### A Pluto.jl notebook ###
# v0.19.29

using Markdown
using InteractiveUtils

# This Pluto notebook uses @bind for interactivity. When running this notebook outside of Pluto, the following 'mock version' of @bind gives bound variables a default value (instead of an error).
macro bind(def, element)
    quote
        local iv = try Base.loaded_modules[Base.PkgId(Base.UUID("6e696c72-6542-2067-7265-42206c756150"), "AbstractPlutoDingetjes")].Bonds.initial_value catch; b -> missing; end
        local el = $(esc(element))
        global $(esc(def)) = Core.applicable(Base.get, el) ? Base.get(el) : iv(el)
        el
    end
end

# ╔═╡ 611932e2-de7a-4480-83cf-79ca5665edf5
begin
	using PlotlyBase, HypertextLiteral, PlutoUI, PlutoTeachingTools
	using CSV, DataFrames, Dates, PeriodicalDates, StatsBase, NLsolve
end

# ╔═╡ 1d00ce38-b7b7-11ed-21b2-23629620f248
function Base.show(io::IO, mimetype::MIME"text/html", plt::PlotlyBase.Plot)
       # Remove responsive flag on the plot as we handle responsivity via ResizeObeserver and leaving it on makes the div flickr during updates
	hasproperty(plt,:config) && plt.config.responsive && (plt.config.responsive = false)   
	show(io,mimetype, @htl("""
			<div>
			<script id=asdf>
			const {plotly} = await import("https://cdn.plot.ly/plotly-2.2.0.min.js")
			const PLOT = this ?? document.createElement("div");
		

		
			Plotly.react(PLOT, $(HypertextLiteral.JavaScript(PlotlyBase.json(plt))));


		
			const pluto_output = currentScript.parentElement.closest('pluto-output')

			const resizeObserver = new ResizeObserver(entries => {
				Plotly.Plots.resize(PLOT)
			})

			resizeObserver.observe(pluto_output)

			invalidation.then(() => {
				resizeObserver.disconnect()
			})
		
			return PLOT
			</script>
			</div>
	"""))
end;

# ╔═╡ 261f6b80-9e5f-460f-a32b-6c23c2e097a8
html"""
<picture>
  <source srcset="https://gci.iscte-iul.pt/2022/identidade/files/brand_v2/escolas/rgb/ibs/en/horizontal/negative/rgb_ibs_en_horizontal_negative.png" media="(prefers-color-scheme: dark)" width="240px!important" style="float:right;">
  <img src="https://gci.iscte-iul.pt/2022/identidade/files/brand_v2/escolas/rgb/ibs/en/horizontal/main/rgb_ibs_en_horizontal_main.png" width="240px" style="float:right;">
</picture>
<title>Macroeconomia</title>
<subtitle>Teste Modelo</subtitle>
<semester>Licenciatura em Gestão<br>1.º Semestre 2022-23</semester>
<author>Vivaldo Mendes, Luís Clemente-Casinhas, Ricardo Gouveia-Mendes</author>
"""

# ╔═╡ 2d509cd9-2838-48c9-951e-01853b0d2dab
@bind nome TextField(66, placeholder="Nome")

# ╔═╡ f9d4524e-1b2b-4e64-b05a-657475ae6cb4
@bind numero TextField(placeholder="Número de aluno")

# ╔═╡ 48640531-2ed5-4856-a4fb-bf56617792ea
md"""
> O teste é composto por 40 questões de **escolha múltipla**. Em cada questão, selecione **a alternativa correta**, a menos que lhe seja indicada outra coisa.
>
> Cada pergunta de escolha múltipla tem a cotação de **0.5 pontos**.
>
> Respostas **erradas descontam -0.125 pontos**.
>
> É esperado que este teste modelo **demore apenas 1h a responder**.
>
> ---
>
> **NOTA:** No teste a sério, haverá 50 perguntas e o tempo de resolução será de 1h30.
"""

# ╔═╡ a5d98aa9-ffe5-4f01-8503-df133181eb24
md"---"

# ╔═╡ 5f6cc1d0-fd4a-4f30-a63e-bf2ea6cbe017
md"""
Por estrutura de um modelo entende-se:

**a)** A robustez teórica com que foi construído.

**b)** O conjunto de variáveis cuja evolução o modelo pretende explicar.

**c)** O conjunto de variáveis determinadas fora do modelo.

**d)** O conjunto de parâmetros que estabelecem uma relação quantitativa entre as variáveis.

**e)** Nenhuma das anteriores.
"""

# ╔═╡ 3b595c53-0a3b-4730-9848-d9cc9361e427
@bind q01 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ dec4bfa3-6ba7-477b-9747-127b71ffa4ba
md"---"

# ╔═╡ b38c78f3-96ab-433f-92fe-491fe697ef34
md"""
Os ciclos económicos correspondem a:

**a)** Desvios entre o PIB real e a sua tendência, no curto-prazo.

**b)** Variações da tendência de longo-prazo do PIB.

**c)** Saltos de nível do PIB, resultantes de diferenças na produtividade.

**d)** Variações da tendência de curto-prazo do PIB.

**e)** Nenhuma das anteriores.
"""

# ╔═╡ c2a1d992-a97a-4523-b795-b2da885d1a4a
@bind q02 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ a484e20f-7abb-4bf2-ac3c-7a75ac9cd81a
md"---"

# ╔═╡ 15c9273b-23d4-4682-8fa8-e0cbe24031b0
md"""
Por PIB potencial entende-se:

**a)** o valor máximo que a variável atinge numa determinada série temporal.

**b)** o valor dado por uma tendência estatisticamente determinada.

**c)** o valor ideal do PIB, admitindo que não há desemprego.

**d)** o valor do PIB excluído o efeito da inflação.

**e)** o valor do PIB quando a sua taxa de crescimento é máxima numa determinada série temporal.
"""

# ╔═╡ 833a499e-9563-4008-a246-9e3ab7237307
@bind q03 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ b31e4f8a-8afb-4c10-94a9-82161da50141
md"---"

# ╔═╡ f3cd9ffa-1028-4290-9d96-c996a95efbeb
md"""
Num modelo macroeconómico existem variáveis endógenas e exógenas. Selecione a **opção falsa** sobre variáveis exógenas:

**a)** É determinada fora de um modelo

**b)** Pode determinar outras variáveis endógenas

**c)** Pode ser determinada por outras variáveis exógenas noutro modelo.

**d)** Pode ser classificada como variável endógena noutro modelo

**e)** Não pode determinar variáveis exógenas nem endógenas
"""

# ╔═╡ d3fe7b23-e2b0-4d38-97af-8d05d838348a
@bind q04 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ 27409c5b-c8da-4135-9c23-227072898a11
md"---"

# ╔═╡ 9954abd1-c0f6-475c-a566-01c5235fb7fd
md"""
Para uma dada economia, sabe-se que: PIB real = 10 e que PIB Potencial = 8 (ambos os valores logarítmicos). Selecione a opção correta.

**a)** A economia encontra-se numa recessão e o hiato do produto é igual a 2.

**b)** A economia encontra-se num boom económico e o hiato do produto é igual a -2.

**c)** A economia encontra-se numa recessão e o hiato do produto é igual a -2.

**d)** A economia encontra-se num boom económico e o hiato do produto é igual a 2.

**e)** O PIB Potencial não tem nada a ver com o PIB real.
"""

# ╔═╡ 9ba5a92a-b60a-4e16-b7c5-06adf55a1a26
@bind q05 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ 404cab40-7472-45a0-bf29-2666d83fb60d
md"---"

# ╔═╡ 5d7a6a08-d59a-4bf1-8020-2cbd449abcc9
md"""
O modelo matemático que se apresenta de seguida é um modelo típico macroeconómico, incluindo variáveis exógenas, variáveis endógenas, e parâmetros.

$$\begin{aligned} & y_1=a+0.5 y_2-2.5 y_3 \\
 & y_2=-2 y_1+5 y_3+b \\ 
& y_3=10 y_1 - 0.1 y_2 +2 c  \\
 & a=10, b=2, c=5 \end{aligned}$$

O modelo pode ser caracterizado da seguinte forma:

**a)** 3 variáveis endógenas $(y_1, y_2, y_3)$, 3 variáveis exógenas $(a, b, c)$, e 3 parâmetros

**b)** 3 variáveis endógenas $(y_1, y_2, y_3)$, 3 variáveis exógenas $(a, b, c)$, e 9 parâmetros

**c)** 3 variáveis endógenas $(a, b, c)$, 3 variáveis exógenas $(y_1, y_2, y_3)$, e 9 parâmetros

**d)** 3 variáveis endógenas $(a, b, c)$, 3 variáveis exógenas $(y_1, y_2, y_3)$, e 3 parâmetros

**e)** Nenhuma das anteriores
"""

# ╔═╡ 74a31c25-c0c7-4ca1-a7a4-b44dc6552c91
@bind q06 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ ea3f6fe6-5a61-4f0f-8d36-417bdfce8963
md"---"

# ╔═╡ 3ff3ec3c-559d-4fe3-ba28-444b63936319
md"""
O modelo matemático que se apresenta de seguida é um modelo típico macroeconómico, incluindo variáveis exógenas, variáveis endógenas, e parâmetros.

$$\begin{aligned} & y_1=a+0.5 y_2-2.5 y_3 \\
 & y_2=-2 y_1+5 y_3+b \\ 
& y_3=10 y_1 - 0.1 y_2 +2 c  \\
 & a=10, b=2, c=5 \end{aligned}$$

A solução do modelo, através de um método à sua escolha (aconselhamos a utilização do NLsolve), apresenta os seguintes resultados:

**a)** $y_1=5.5$,  $y_2 = 210.667$,  $y_3 = 43.9333$

**b)** $y_1=5.5$,  $y_2 = 10$,  $y_3 = 1.4$

**c)** $y_1=5.5$,  $y_2 = 210.667$,  $y_3 = 0$

**d)** $y_1=5.5$,  $y_2 = 200.5$,  $y_3 = 50.8$

**e)** Nenhuma das anteriores
"""

# ╔═╡ 69ed0a79-57f6-4411-94db-7805b1fdf942
# Célula para utilização livre

# ╔═╡ 8ec6fe02-415b-4994-960f-aec51f3d0620
# Célula para utilização livre

# ╔═╡ e28a931f-5209-44cb-b93d-d91e7c875611
@bind q07 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ 4b4ff1f1-989c-4323-88e9-913e9ff46e4a
md"---"

# ╔═╡ 3ba6660b-b6af-4d44-8f2b-a08f344cdc82
md"""
Considere as seguintes informações sobre uma dada economia: PNB=150, PIB=200 e Depreciação=20. Selecione a opção correta.

**a)** O valor do Rendimento Líquido dos Fatores Produtivos é igual a 50.

**b)** O valor do Rendimento Líquido dos Fatores Produtivos é igual a 250.

**c)** O valor do Rendimento Nacional Total é igual a 100.

**d)** O valor do Rendimento Nacional Total é igual a 170.

**e)** Nenhuma das anteriores.
"""

# ╔═╡ c3ca6b71-80b8-45b6-a6d9-3c3f7f498219
# Célula para utilização livre

# ╔═╡ 2a3913df-458d-4ee5-b25b-358bfbaec776
# Célula para utilização livre

# ╔═╡ d1ddef1f-717a-451d-b6d7-a765edab8ba7
@bind q08 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ 25296a5f-6083-4cd9-b85c-d338ae761d51
md"---"

# ╔═╡ e9c43033-18c3-462a-9935-cd3439c15dff
md"""

Considere uma economia onde apenas se produzem os seguintes bens:

| Bens  |   |  $~~~~~~~~~~~~~~$ Ano 1 |      |    ||$~~~~~~~~~~~~~~$Ano 2||
|:----  |---| :----:         | :----: |   ---|--- |:----:        | :----: |
| | $~~$    | Quantidades    | Preços |      |    |Quantidades   | Preços |
|Porcos |   | 2000           | 2      |      |    |2100          | 2.1    |
|Vacas  |   | 400            | 10     |      |    |410           | 11.5   |

Os valores são para o Notebook na próxima célula.

**Use estes dados para responder às próximas seis perguntas.**
"""

# ╔═╡ dc1cbb96-141a-4d95-99d3-3de916cc89a6
begin 
	#    ano 1               ano 2 
	Qp_1 = 2000    ;     Qp_2 = 2100         # Quantidade de Porcos 
	Qv_1 =  400    ;     Qv_2 =  410         # Quantidade de Vacas
	Pp_1 =    2    ;     Pp_2 =    2.1       # Preço dos Porcos 
	Pv_1 =   10    ;     Pv_2 =   11.5       # Preço das Vacas 
end;

# ╔═╡ 3ca2c3bf-4652-455e-ae96-29f15161c3fe
md"""
Utilizando o ano 1 como o ano base, qual é o valor do PIB real para o ano 1?

**a)** 8000

**b)** 8300

**c)** 8800

**d)** 9125

**e)** Nenhuma das anteriores
"""

# ╔═╡ b4585a7c-03e9-4279-ac20-293acd4ec2b4
# Célula para utilização livre

# ╔═╡ 54362cca-6b1e-4fa9-b202-bd1518f6a8c9
@bind q09 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ 0268a10c-6769-4b2a-b4cf-148d4aaeb10c
md"""
Utilizando o ano 1 como o ano base, qual é o valor do PIB real para o ano 2?

**a)** 8000

**b)** 8300

**c)** 8800

**d)** 9125

**e)** Nenhuma das anteriores
"""

# ╔═╡ a4ac8f58-7752-430a-b937-eee6c4c8c662
# Célula para utilização livre

# ╔═╡ a035830d-059a-471d-a758-ce73ee6bfaec
@bind q10 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ 43d9f556-f18f-438d-b20e-09a4d6e99b7a
md"""
Utilizando o ano 1 como o ano base, qual é a taxa de crescimento real do PIB?

**a)** 14%

**b)** 5.1%

**c)** 3.75%

**d)** 0.0%

**e)** Nenhuma das anteriores
"""

# ╔═╡ d40a4975-d38a-4e76-b5fd-9cfbf1feb2c7
# Célula para utilização livre

# ╔═╡ 82f91003-e90d-4407-9b61-0f7129774686
@bind q11 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ 5363e9d9-9ca7-4556-b432-7ddaab6229e8
md"""
Utilizando o ano 1 como o ano base, qual o valor do índice de preços do PIB para o ano 1?

**a)** 1.0000

**b)** 1.0994

**c)** 0.9096

**d)** 0.9999

**e)** Nenhuma das anteriores
"""

# ╔═╡ 2f6833e4-d254-432c-85fa-aa4fff517ee6
# Célula para utilização livre

# ╔═╡ 755e7616-4c9a-4e9a-bfa2-d1bde2ea668c
@bind q12 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ 10265196-7cf1-485c-9076-658486f981a5
md"""
Utilizando o ano 1 como o ano base, qual o valor do índice de preços do PIB para o ano 2?

**a)** 1.0000

**b)** 1.0994

**c)** 0.9096

**d)** 0.9999

**e)** Nenhuma das anteriores
"""

# ╔═╡ 85af9164-07bf-4a10-9162-8668358d3579
# Célula para utilização livre

# ╔═╡ dec4f528-6cad-42f3-84b8-5a0bca93b561
@bind q13 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ 6875e3cb-8bda-4a5d-be91-38584e939f85
md"""
Utilizando o ano 1 como o ano base, qual a taxa de inflação nesta economia entre estes dois anos?

**a)** 0.00%

**b)** 9.94%

**c)** 3.75%

**d)** -9.04%

**e)** Nenhuma das anteriores
"""

# ╔═╡ ea25215f-6df8-40de-ac35-6f8136545e74
# Célula para utilização livre

# ╔═╡ ce248b19-26df-47ff-8294-11cd903611e3
@bind q14 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ 1e0c740c-a4a5-43cc-a9cd-f4e43065ccbd
md"""
Qual é o valor do PIB nominal para o ano 1?

**a)** 8000

**b)** 8300

**c)** 8800

**d)** 9125

**e)** Nenhuma das anteriores
"""

# ╔═╡ 6f5d3464-4058-455c-ab29-48b25a7d198a
# Célula para utilização livre

# ╔═╡ 3e402c14-ef27-43e7-b189-6598fa374949
@bind q15 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ ddd0dd83-a842-4f96-b258-f8378f508b0d
md"""
Qual é o valor do PIB nominal para o Ano 2?

**a)** 8000

**b)** 8300

**c)** 8800

**d)** 9125

**e)** Nenhuma das anteriores
"""

# ╔═╡ 8c466cb3-a6e0-4c70-bea5-1686e990bb21
# Célula para utilização livre

# ╔═╡ 4d86456c-3c50-490e-b45c-2735cb772a25
@bind q16 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ c32ca801-ef2a-40b1-bbc4-b7e028872136
md"""
Qual é o valor da taxa de crescimento nominal do PIB?

**a)** 14.06%

**b)** 5.12%

**c)** 3.75%

**d)** 0.00%

**e)** Nenhuma das anteriores
"""

# ╔═╡ 7e373f54-b88b-4284-9590-decea0eb296f
# Célula para utilização livre

# ╔═╡ 2bb34c87-8859-4ed6-86fc-d2f48296c407
@bind q17 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ cf0b0df7-c855-42ca-b39a-988709298dcc
md"---"

# ╔═╡ 2e58c3b1-f6f8-4bdb-8b64-d47286f98011
md"""
A taxa de desemprego mede, em determinado momento:

**a)** A percentagem de trabalhadores que não têm emprego.

**b)** A percentagem de trabalhadores que não têm emprego, mas procuram trabalho.

**c)** A percentagem de trabalhadores que param de trabalhar.

**d)** A percentagem de trabalhadores que procuram trabalho.

**e)** Nenhuma das anteriores.
"""

# ╔═╡ e0f3a463-2009-4aee-8007-82a19c430ece
@bind q18 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ db7a69bb-f359-4695-acbd-7065321b4248
md"---"

# ╔═╡ 20c632ce-4e27-40f9-95d7-6e2f1d8140eb
md"""
Se a família Albuquerque adquirir uma moradia à família Cardoso por 2 milhões de euros, que esta comprara 5 anos antes por 0.7 milhões, o impacto no PIB é de:

**a)** Aumentar 1.3 milhões de euros.

**b)** Aumentar 2 milhões de euros.

**c)** Aumentar 2.7 milhões de euros.

**d)** Não há dados suficientes para calcular o impacto sobre o PIB.

**e)** Nenhuma das anteriores.
"""

# ╔═╡ 213afe7d-dce9-4e2d-bd9a-7eec0b15adce
@bind q19 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ 009bd98d-cab3-404a-a34d-efe486f7a927
md"---"

# ╔═╡ 0c2ff35a-0781-47d8-9457-e396e41b1449
md"""
![](https://vivaldomendes.org/images/Tests/RIR.png)

Na figura acima, o período entre 1980 e 2000 diz-nos que:

**a)** A taxa de juro nominal é em geral negativa.

**b)** A taxa de inflação é em geral negativa.

**c)** A diferença entre a taxa de juro nominal e a taxa de inflação é em geral positiva.

**d)** A taxa de inflação é em geral positiva.

**e)** Nenhuma das anteriores.
"""

# ╔═╡ 9701c62c-84bc-49cf-9824-cd0247037fee
@bind q20 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ 67745071-5308-4657-adf7-85675210d824
md"---"

# ╔═╡ bfd8f8de-935b-4f35-b548-1a52b08d6676
md"""
Selecione a opção **incorreta**. O Produto Nacional Bruto ou Despesa Nacional:

**a)** Considera o valor de mercado dos bens e serviços finais.

**b)** Considera o valor de mercado dos bens e serviços produzidos no espaço geográfico de um país.

**c)** Considera um determinado período temporal.

**d)** Considera o valor de mercado dos bens e serviços produzidos por fatores produtivos nacionais.

**e)** Pode ser obtido através da soma do Rendimento Nacional Total e da Depreciação.
"""

# ╔═╡ da351fcd-c23d-4879-a17f-2022095a1fc3
@bind q21 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ b50323a4-18ab-4f2d-bbca-40fdc81ede0a
md"---"

# ╔═╡ b38edbde-eac9-4692-9124-05abffff1c6c
md"""
Selecione a opção **incorreta**. O Produto Interno Bruto:

**a)** Considera o valor de mercado dos bens e serviços finais.

**b)** Considera o valor de mercado dos bens e serviços produzidos no espaço geográfico de um país.

**c)** Considera um determinado período temporal.

**d)** Considera o valor de mercado dos bens e serviços produzidos por fatores produtivos nacionais.

**e)** Pode ser medido através da ótica da despesa, produção e rendimento.
"""

# ╔═╡ 6a10ce3b-84b9-4ffa-ab7d-44bd87b0369d
@bind q22 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ 4ef7feb3-4b57-462d-868c-c075ffb040a4
md"---"

# ╔═╡ 830aba1b-c6d1-4bfc-9c04-0a58f6966fd9
md"""
Um aumento na taxa de juro real afeta negativamente o nível do PIB devido ao facto de:

**a)** Levar a uma redução no nível do Consumo privado, do Investimento, e das Exportações líquidas

**b)** Levar a um aumento no nível do Consumo privado e do Investimento, e das Exportações líquidas

**c)** Levar a uma redução no nível dos Gastos públicos e das Exportações

**d)** Levar a uma redução no nível do Consumo autónomo (exógeno) e do Investimento autónomo (exógeno)

**e)** Nenhuma das anteriores
"""

# ╔═╡ 0ec3bd71-1497-43be-9d96-7d445378b66d
@bind q23 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ e39915c4-afc7-4f9b-81d1-ea4b87f67010
md"---"

# ╔═╡ 7ffed666-976e-4b09-afb1-62e57f506ec9
begin
	C̄ = 2.0;  Ī = 1.5 ;  Ḡ = 2.5;  T̄ = 2.5; N̄X̄ = 1.0; f̄ = 1.0; c = 0.5; b = 0.1; d = 0.5; x = 0.15;
	Ā = C̄ + Ī - d*f̄ + Ḡ + N̄X̄ - c*T̄
    m = 1/(1-c)
    ϕ = b + d + x

	Y = 0.0:0.01:15.0
	r = (Ā./ ϕ) .- (1. /(m .* ϕ)).*Y
	
	trace4_1 = scatter(; x=Y, y = r, mode="lines" , line_color = "Blue", line_width = "3",
					name  = "IS")
	
	trace4_2 = scatter(; x = [6.0, 9.0], y = [3.0, 1.0], text =["1", "2"], textposition = "top center", 
                    name ="Eq.", mode="markers+text", marker_size= "12", marker_color="Blue", 
					textfont = attr(family="sans serif", size=16, color="black"))

	
	trace4_4A = scatter(; x = [7.0, 8.0], y = [1.0, 3.0], text =["2'", "1'"], textposition = "top center", 
                    name ="Eq.", mode="markers+text", marker_size= "12", marker_color="Red", 
					textfont = attr(family="sans serif", size=16, color="black"))
	
	layout4_2 = Layout(;
					title_text = "A Curva IS", 
					title_x = 0.5,
					hovermode="x",
                    xaxis=attr(title="GDP in trillion dollars (Y)", showgrid=true, zeroline=false),
                    xaxis_range = [2.9, 12.0],
					yaxis_range = [-1.0, 5.0],
                    yaxis=attr(title="Real interest rate (r)", zeroline = false))

   p4_2 = Plot([trace4_1, trace4_2, trace4_4A], layout4_2)
end

# ╔═╡ a549cda6-ffe9-4d53-8901-72a772ac4030
md"""
Usando a figura "A Curva IS" e sabendo que o valor do multiplicador $m$ é $(m), a economia desloca-se do ponto 2 para o ponto 2', devido ao facto de:

**a)** O Consumo Exógeno $(\overline{C})$ ter aumentado em 1 trilião de dólares

**b)** O Consumo Exógeno $(\overline{C})$ ter diminuído em 1 trilião de dólares

**c)** A taxa de juro real $(\overline{r})$ ter diminuído em 1 ponto percentual (1 pp)

**d)** O Consumo Exógeno $(\overline{C})$ ter diminuído em 2 triliões de dólares

**e)** Nenhuma das anteriores
"""

# ╔═╡ ebc7edcb-b59c-4c9c-88dc-b7d7b63df26e
# Célula para utilização livre

# ╔═╡ de93410d-ea4a-4c96-bf1b-3e44c54f1b0d
@bind q24 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ 3775de97-2b1e-48b6-bec5-c5c572d15812
md"""
Usando novamente a figura "A Curva IS" acima, a economia desloca-se do ponto 1 para o ponto 2, devido ao facto de:

**a)** As Exportações terem diminuído

**b)** A taxa de juro real ter aumentado

**c)** Os Impostos terem aumentado

**d)** A inflação ter diminuído

**e)** Nenhuma das anteriores
"""

# ╔═╡ 5c09ffd1-be5f-4fa4-b4b0-fd6b44604bd1
@bind q25 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ ed296d0f-5395-48d7-946f-a7a400801a8c
md"---"

# ╔═╡ 93440b5b-e3e9-4eee-b9e8-ea6d0b7a9287
md"""
Se o rendimento disponível diminui, a despesa em consumo diminui:

**a)** Num montante que depende da taxa de juro real.

**b)** Num montante que depende do consumo autónomo.

**c)** Num montante inferior à diminuição do rendimento disponível.

**d)** Num montante que depende do multiplicador monetário.

**e)** Nenhuma das anteriores
"""

# ╔═╡ 9f0a60ef-5f58-4990-a7b9-43b62f4eaca2
@bind q26 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ 8d96d7a0-f07e-498d-aac7-81e91cc237fd
md"---"

# ╔═╡ cac8d227-1c29-463e-a06f-ee34a446346d
md"""
Se os agentes económicos se sentirem otimistas relativamente ao futuro da economia:

**a)** O consumo autónomo pode aumentar.

**b)** O investimento autónomo pode diminuir.

**c)** A curva IS poderá deslocar-se para a esquerda.

**d)** A curva IS poderá deslocar-se para baixo.

**e)** Nenhuma das anteriores.
"""

# ╔═╡ b9acc04f-83e7-4847-a042-c0906275c333
@bind q27 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ bc72113c-3b60-4271-afe4-f763c45b80a9
md"---"

# ╔═╡ ea62e80d-1110-4a3e-8d3d-ff5c202fe795
md"""
Perante uma subida da taxa de juro real espera-se:

**a)** uma deslocação da curva IS para a direita.

**b)** uma deslocação da curva IS para a esquerda.

**c)** uma deslocação ao longo da curva IS.

**d)** uma rotação da curva IS sobre o ponto de equilíbrio, de modo que aumenta o declive.

**e)** uma rotação da curva IS sobre o ponto de equilíbrio, de modo que diminui o declive.
"""

# ╔═╡ 828c3ac9-565c-4aa4-a2ab-92a13f930c7d
@bind q28 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ a0aeeb0f-8566-4285-9e52-babf94caad78
md"---"

# ╔═╡ a59abfd2-c6fd-40b3-9887-b59f198f9f7a
md"""
Qual o significado económico da Procura Autónoma?

**a)** É uma variável endógena que representa um valor de bens e serviços desejados numa certa economia que não é sensível a variações da taxa de juro.

**b)** É uma variável exógena que representa um valor de bens e serviços desejados numa certa economia que não é sensível a variações da taxa de juro.

**c)** É uma variável endógena que representa um valor de bens e serviços desejados numa certa economia que não é sensível a variações da taxa de inflação.

**d)** É uma variável exógena que representa um valor de bens e serviços desejados numa certa economia que é sensível a variações da taxa de juro.

**e)** É uma variável exógena que representa um valor de bens e serviços desejados numa certa economia que é sensível a variações da taxa de inflação.
"""

# ╔═╡ 2143b654-b15a-4b84-8997-eb8734cc4ca2
@bind q29 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ 2436361d-d227-40ec-bd5f-887e22c46cc0
md"---"

# ╔═╡ f067f58d-74e7-4b58-a9aa-69df7503f559
md"""
O Princípio de Taylor:

**a)** É refletido pelo declive negativo da curva MP e implica que a variação da taxa de juro nominal tem de ser proporcionalmente superior à variação da taxa de inflação.

**b)** É refletido pelo declive positivo da curva MP e implica que a variação da taxa de juro nominal tem de ser proporcionalmente superior à variação da taxa de inflação.

**c)** É refletido pelo declive negativo da curva MP e implica que a variação da taxa de juro nominal tem de ser proporcionalmente inferior à variação da taxa de inflação.

**d)** É refletido pelo declive positivo da curva MP e implica que a variação da taxa de juro nominal tem de ser proporcionalmente inferior à variação da taxa de inflação.

**e)** Nenhuma das anteriores
"""

# ╔═╡ 30248794-18ab-4779-8f4f-bce3c2c4a0a2
@bind q30 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ 2361966e-972f-4521-8134-c49be48ae92f
md"---"

# ╔═╡ 697fece3-4f08-4041-9d48-159d06c342ab
md"""
Certo banco central obteve os seguintes dados sobre a procura agregada:
- Procura autónoma: $\overline{A} = 5.4$
- Multiplicador: $m= 2.0$
- Parâmetro que resume o impacto de $r$ sobre a procura agregada: $\phi=0.2$
- A política monetária traduz-se na expressão: $r=\overline{r}+\lambda \pi$, com $\overline{r}=1.5\%$ e $\lambda = 0.5$.

Tenha em conta que as percentagem estão expressas em valores percentuais, tal que $2\%$ é simplesmente $2$.

As curvas AD e MP estão representadas em baixo.
"""

# ╔═╡ db3b2a15-9c32-4361-b3cc-15e9ab0b165d
Ā3 = 6.5 ;	m3 = 2.0 ;	ϕ3 = 0.2 ;	r̄3 = 1.5 ;	λ3 = 0.5 ;

# ╔═╡ ab7f1c7c-c3a2-4f20-957a-44a3c1bf0f6f
function fig_3c1()
		r3 = 0.0:0.01:7.0
		π3 = - (r̄3 ./ λ3) .+  r3 ./ λ3
	
		trace5_7 = scatter(; x = r3, y = π3, mode="lines" , line_color = "Brown", line_width = "3",
					name  = "MP")
	
		trace5_8 = scatter(; x = [2.0 , 3.0], y = [1.0 , 3.0], text =["1", "2"], 
					textposition = "top center", name ="Eq.", mode="markers+text", marker_size= "12",
					marker_color="Brown", textfont = attr(family="sans serif", size=16, color="black"))
	
	
		layout5_8 = Layout(;
					title_text ="Curva MP", 
					title_x = 0.5,
					hovermode = "x",
                    xaxis=attr(title=" Taxa de juro real (r)", showgrid=true, zeroline=false),
                    xaxis_range = [0.98, 4.0],
                    yaxis=attr(title="Taxa de inflação (π)", zeroline = false),
					yaxis_range=[-1.0 , 5.0])

   		p5_8 = Plot([trace5_7, trace5_8], layout5_8)
end;

# ╔═╡ 9398b1bd-9513-4969-9f0c-c94867e14250
function fig_3c2()
		Y3 = 10.0:0.01:14.0

		πdmax3 = (Ā3 / (λ3 * ϕ3)) - r̄3/λ3 		# The AD curve y-axis intercept 

		πd3 = πdmax3 .- ((1 ./(m3 .* ϕ3 .* λ3)) .* Y3)
	
		trace5_9 = scatter(; x = Y3, y = πd3, mode="lines" , line_color = "Blue", line_width = "3",
					name  = "AD")
	
		trace5_10 = scatter(; x = [12.2 , 11.8], y = [1.0 , 3.0], text =["1", "2"], 
					textposition = "top center", name ="Eq.", mode="markers+text", marker_size= "12",
					marker_color="Blue", textfont = attr(family="sans serif", size=16, color="black"))
	
	
		layout5_10 = Layout(;
					title_text ="Curva AD", 
					title_x = 0.5,
					hovermode = "x",
                    xaxis=attr(title=" PIB em triliões de dólares (Y)", showgrid=true, zeroline=false),
                    xaxis_range = [11.4, 12.6],
                    yaxis=attr(title="Taxa de inflação (π)", zeroline = false),
					yaxis_range=[-1.0 , 5.0]
					)
					

   		p5_10 = Plot([trace5_9, trace5_10], layout5_10)
end;		

# ╔═╡ f56ba891-4e6d-4af7-91c3-b8bc615b2a90
begin
	p5_10A = [fig_3c1() fig_3c2()]
	relayout!(p5_10A, hovermode = "x")
	p5_10A
end

# ╔═╡ 7bfdc001-59ac-496d-b98a-87b6792ad245
md"""
Se a taxa de inflação for $2\%$:

**a)** A taxa de juro real será de 3.5%.

**b)** O PIB será de 12.2 triliões de dólares.

**c)** A taxa de juro definida pelo Banco Central será de 6%.

**d)** O PIB será de 12 triliões de dólares.

**e)** Nenhuma das anteriores.
"""

# ╔═╡ 108a0ddf-f0b1-4b8c-af17-11fea5f4da29
@bind q31 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ 1a501673-45e9-4dc8-a516-72e235679b5b
md"---"

# ╔═╡ adbc4189-fde1-4089-a91e-738ed8713e3e
md"""
Assuma que a curva de Política Monetária (MP) é dada pela seguinte expressão: 

$$\quad r = 1.0 + 0.25 \pi \tag{MP}$$

A seguinte informação é conhecida sobre a procura agregada:
- Procura Autónoma: $\overline{A} = 7.0$
- O multiplicador: $m= 2.0$
- O conjunto de parâmetros que dão o impacto de $r$ sobre a procura agregada: $\phi=0.5$

A curva AD desta economia é dada pela expressão:

**a)** $Y = 14 -0.25\pi$

**b)** $Y = 13.5 -0.125\pi$

**c)** $Y = 13 -0.25\pi$

**d)** $Y = 16 -0.5\pi$

**e)** Não há dados suficientes para calcular a expressão da curva AD.
"""

# ╔═╡ b369730d-87cc-42f5-8c55-913bcf953e03
# Célula para utilização livre

# ╔═╡ bd71d4c9-6bde-4b39-ac85-450732654487
# Célula para utilização livre

# ╔═╡ e8eac1f1-cb50-4869-939b-f000667f054e
@bind q32 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ c41d57d6-acab-43d9-8202-a0130223d961
md"---"

# ╔═╡ 2c4b1a34-9215-4108-b293-1df907be1c48
md"""
Considere que o multiplicador Keynesiano é igual a 2.5. Se se der um aumento de impostos em $2 milhões:

**a)** O PIB aumenta em $5 milhões

**b)** O PIB aumenta menos que $5 milhões

**c)** O PIB diminui em $5 milhões

**d)** O PIB diminui menos que $5 milhões

**e)** Nenhuma das anteriores.
"""

# ╔═╡ 25b1c192-1213-490e-8f7b-12ad12bc17f3
@bind q33 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ 6a992b69-8359-4898-baee-beb17a7ad3e2
md"---"

# ╔═╡ 9c47ee9b-5990-47f8-83c0-8cb85f51be87
md"""
A curva MP:

**a)** Demonstra graficamente como os Bancos Centrais respondem a mudanças da taxa de inflação com mudanças na taxa de juro real.

**b)** Reflete o impacto da taxa de juro no PIB real.

**c)** Explica os desvios de curto prazo do PIB real e da taxa de inflação.

**d)** Reflete o impacto da taxa de inflação.

**e)** Nenhuma das anteriores.
"""

# ╔═╡ 5f84e4b7-2e65-4402-b1a8-bd2b43a56aa7
@bind q34 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ 44a6ab14-24cf-4bef-8542-f211c6bb29ff
md"---"

# ╔═╡ fb4c3ba2-06aa-4dcf-b34e-21b340d8f69a
md"""
Uma política monetária mais restritiva envolve:

**a)** Aumentar a taxa de juro real e deslocar  a curva MP para a direita.

**b)** Aumentar a taxa de juro real e deslocar a curva MP para a esquerda.

**c)** Diminuir a taxa de juro real e deslocar a curva MP para a esquerda.

**d)** Diminuir a taxa de juro real e deslocar a curva MP para a direita.

**e)** Nenhuma das anteriores.
"""

# ╔═╡ cea2f32d-f419-49c2-8daa-45c3a62c0aab
@bind q35 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ 5bcb419b-db52-4a3b-8fb8-96cc1aafe6b6
md"---"

# ╔═╡ 70237c4a-08b8-45a3-9f0d-897771ae4658
md"""
A curva AD:

**a)** Traduz a relação entre o PIB e a taxa de inflação, para um determinado nível de procura autónoma, quando o mercado de bens e serviços está em equilíbrio.

**b)** Mostra que um aumento no consumo autónomo, no investimento autónomo, nas exportações líquidas autónomas e na despesa pública, diminui o PIB para qualquer taxa de inflação.

**c)** Mostra que um aumento dos impostos leva a um aumento do PIB para qualquer taxa de inflação.

**d)** Traduz a relação entre o PIB e a taxa de juro real, para um determinado nível de procura autónoma, quando o mercado de bens e serviços está em equilíbrio.

**e)** Nenhuma das anteriores.
"""

# ╔═╡ 0097eaef-53a7-4aab-b20d-4357f12eaf9b
@bind q36 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ a91fa2b0-070d-44fc-9830-e6f6c236d62c
md"---"

# ╔═╡ d0050dd5-1398-460d-a28d-dc8a1e846b11
md"""
Quando a Fed quer diminuir o nível de reservas do sistema bancário $(R)$, pode:

**a)** Comprar títulos do tesouro.

**b)** Aumentar os empréstimos aos Bancos.

**c)** Vender títulos do tesouro.

**d)** Aumentar o rácio de reservas legais.

**e)** Nenhuma das anteriores.
"""

# ╔═╡ 365d69fc-5d2b-4b57-a426-601809e2ca42
@bind q37 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ b5f8267d-31ea-4e02-881e-26a1249221da
md"---"

# ╔═╡ 626fb86c-1b4d-43a1-bf47-26a95402654c
md"""
Por Base Monetária entende-se:

**a)** um passivo do Banco Central que corresponde ao conjunto de moedas e notas em circulação e às reservas dos bancos comerciais junto do Banco Central.

**b)** um ativo do Banco Central que corresponde ao valor de títulos de dívida pública detidos pelo Banco Central.

**c)** um passivo do Banco Central que corresponde ao valor de títulos de dívida pública detidos pelo Banco Central.

**d)** um ativo do Banco Central que corresponde ao conjunto de moedas e notas em circulação e notas em circulação e às reservas dos bancos comerciais junto do Banco Central.

**e)** Nenhuma das anteriores.
"""

# ╔═╡ 87cac9dc-3c77-4aca-bb20-6ad9b6e201b8
@bind q38 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ b9236494-eb3a-4ba8-9196-92188e72fbdb
md"---"

# ╔═╡ d8e9d8d5-d32c-41a5-a634-ed79d1a780d9
md"""
Quando a Fed conduz uma venda de títulos em mercado aberto (*open market operation*), as reservas dos bancos comerciais:

**a)** Aumentam para aumentar a liquidez na Economia.

**b)** Aumentam para diminuir a liquidez na Economia.

**c)** Diminuem para aumentar a liquidez na Economia.

**d)** Diminuem para diminuir a liquidez na Economia.

**e)** Nenhuma das anteriores.
"""

# ╔═╡ 719d57fe-8e5e-472a-9a07-d40c34fcf10c
@bind q39 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ 27398a1c-6c62-4f70-bad1-8d95f4fa27f3
md"---"

# ╔═╡ e53494ef-a6cd-4278-bac9-dfda713453f9
md"""
Quando a Fed conduz compras em mercado aberto:

**a)** Compra títulos do tesouro, o que aumenta a Base Monetária.

**b)** Compra títulos do tesouro, o que diminui a Base Monetária.

**c)** Pede dinheiro emprestado aos Bancos Comerciais, o que aumenta a Base Monetária.

**d)** Empresta dinheiro aos Bancos Comerciais, o que diminui a Base Monetária.

**e)** Nenhuma das anteriores.
"""

# ╔═╡ b4b0d6f5-2135-4ba2-a234-14e5c9b37f8b
@bind q40 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ 9f88959d-7765-4e32-b4b1-fc1ee4a57672
md"---"

# ╔═╡ c1ba126a-95b8-4998-b1eb-66b61197fc8f
md"""
!!! danger "Instruções finais"

	Concluiu a prova.

	O último passo é confirmar que quer **guardar as suas respostas**, através da **Checkbox depois desta caixa**. Ao carregar, será gerado um **ficheiro `.csv`** na mesma pasta onde está alojado este Notebook.

	**É esse ficheiro que deverá enviar à equipa docente.**

	Antes de enviar, certifique-se que a data/hora do ficheiro fazem sentido. **Só depois deve fechar o Notebook.**
"""

# ╔═╡ ff2c5b60-5f83-412f-9fd7-0bd2a2d405de
md"Confirmo que ao longo da prova procedi sempre de acordo com todas as **normas de ética e de integridade académicas**, isto é, sem qualquer recurso ilícito à luz das normas do ISCTE e, em particular, da Unidade Curricular de Macroeconomia I, pelo que quero **guardar as minhas respostas** a fim de as remeter à equipa docente para o meu trabalho ser devidamente avaliado. $(CheckBox(default=false))"

# ╔═╡ 6a8e0a9d-d727-4daf-a19c-b2fc44ff80c4
md"---"

# ╔═╡ 1576ebf2-0cf9-4870-b12f-b484e081dd67
md"## Células auxiliares"

# ╔═╡ b608842e-a6e5-4a96-baa2-3778e0c53349
md"### Packages"

# ╔═╡ ab06f2b6-207b-47b8-a4bd-0831380b7abc
md"### CSS code"

# ╔═╡ fe7e0122-38ee-4490-b893-54e8a7d8ab07
html"""
<link href="https://fonts.googleapis.com/css?family=Montserrat:300,300italic,700,700italic" rel="stylesheet">

<style>
	main {
		max-width: 1200px;
		padding: 5%;
        display:block;
        margin-left: auto;
        margin-right: auto;
	}
	pluto-output {
		font-family: "Montserrat" !important;
		font-size: 1em;
		line-height: 1.5;
	}
	.plutoui-toc {
		font-family: "Montserrat" !important;
		font-size: 90%;
	}
	.admonition-title {
		font-family: "Montserrat" !important;
	}
	pluto-output h1, h2, h3 {
		font-family: "Montserrat" !important;
		border: none !important;
	}
	pluto-output h1 {
		font-size: 1.8em !important;
		margin-top: 1.5em;
		margin-bottom: 0.5em;
	}
	pluto-output h2 {
		font-size: 1.5em !important;
		margin-top: 1.8em;
		margin-bottom: 1em;
	}
	pluto-output h3 {
		font-size: 1.3em !important;
		margin-top: 1.5em;
		margin-bottom: 1em;
	}
	img:not(picture *) {
		width: 80%;
		display: block;
		margin-left: auto;
		margin-right: auto;
	}
	title {
		font-size: 2.2em;
		display: block;
		font-weight: bold;
		text-align: left;
		margin: 1.5em 0 0em 0;
}
	subtitle {
		font-size: 1.6em;
		display: block;
		text-align: left;
		margin: 0 0 1.5em 0;
}
	author {
		display: block;
		text-align: left;
		padding-bottom: 0.8em;
		border-bottom: 3px solid !important;
}
	email {
		display: block;
		text-align: left;
		margin: 0 0 2.5em 0;
}
	semester {
		font-size: 1.3em;
		display: block;
		text-align: left;
		margin: 0 0 1.5em 0;
}
	.admonition-title {
		font-size: 125%;
	}
	ol {
		list-style-type: lower-alpha;
	}
	li::marker {
		font-weight: bold;
	}
	li {
		margin-top: 1em !important;
		margin-bottom: 1em !important;
	}
	.small {
		font-size: 80%;
	}
	.centered-image {
		display: block;
		margin-left: auto;
		margin-right: auto;
		margin-top: 1em;
		margin-bottom: 1em;
		width: 90%;
	}
	details {
		font-size: 80%;
		margin-left: 3em;
	}
	summary {
		font-size: 125%;
		margin-left: -2.2em;
		margin-top: 0.5em;
		margin-bottom: 0.5em;
	}
	input[type="checkbox"] {
		transform: scale(1.5);
	}
	textarea, input[type="text"] {
		font-family: "Montserrat" !important;
		font-size: 0.85em !important;
		line-height: 1.5;
	}
    pluto-cell>button,pluto-input>button,pluto-shoulder {
    display: none !important;
    }
</style>
"""

# ╔═╡ 1728b392-427a-4f83-aa7e-c5c576d2f362
md"### Internal functions"

# ╔═╡ 4fa02903-e7f3-4e85-b42d-9e97edd42493
function tchanã(ans::Union{Nothing,String},correct::String)	
	if typeof(ans) == Nothing
		md"""
		👆 *Por favor selecione uma resposta.*
		"""
	else
		if ans == correct
			md"""
			!!! tip "🎉 Correto!"
			"""
		else	
			md"""
			!!! danger "👎 Resposta errada"
				
				Tente outra vez. **Mas estude primeiro!!!** 😡
			"""
		end
	end
end;

# ╔═╡ 26117a53-b772-4d76-85b1-d6594f2a66f7
tchanã(q01,"d)")

# ╔═╡ 8a5c4379-c682-4716-9b45-436de5d43ff6
tchanã(q02, "a)")

# ╔═╡ 1d871b5d-9713-469e-abce-45fc9b17fb66
tchanã(q03, "b)")

# ╔═╡ 1e2aa24b-b8ce-4e8d-ac08-3d249a1ab99e
tchanã(q04, "e)")

# ╔═╡ a35daac5-655d-4f14-ba9d-515c44ce804f
tchanã(q05, "d)")

# ╔═╡ 7e06b93b-367c-4922-9bee-768168c8bada
tchanã(q06, "b)")

# ╔═╡ 85e56719-918f-435e-a0f4-6996f4a75fab
tchanã(q07, "a)")

# ╔═╡ a0e5bb9c-0497-434c-b5c4-70d264405a03
tchanã(q08, "a)")

# ╔═╡ 4c56d468-3946-4af4-9a88-e3dae0bc1478
tchanã(q09, "a)")

# ╔═╡ 4134607c-238a-4c94-932e-ed69fe13e89b
tchanã(q10, "b)")

# ╔═╡ 9524aab9-9331-448b-a95a-886df98a68f1
tchanã(q11, "c)")

# ╔═╡ 1675a2b4-7526-459b-a989-440e5dfbea27
tchanã(q12, "a)")

# ╔═╡ 7fae61ee-22d8-462e-b216-6b1dfa427c8e
tchanã(q13, "b)")

# ╔═╡ 8713c067-8b07-426d-baa9-935d7ef9344e
tchanã(q14, "b)")

# ╔═╡ 61e87c19-28ca-4ab3-a8d6-22e41471edec
tchanã(q15, "a)")

# ╔═╡ c27a37a1-6075-4410-8278-2b65cc0415fd
tchanã(q16, "d)")

# ╔═╡ 8e6113de-6165-4dcf-b8fb-dd8618724f4a
tchanã(q17, "a)")

# ╔═╡ 3687c625-69c7-429b-b1a4-a30d9156ca89
tchanã(q18, "b)")

# ╔═╡ eda5742a-c29b-4ff6-9c35-224ac82cb623
tchanã(q19, "e)")

# ╔═╡ 01a5735c-4e85-497f-a6b2-9ccb80cb4977
tchanã(q20, "c)")

# ╔═╡ d4c9f914-6170-4b73-8bc5-65bde9fd66be
tchanã(q21, "b)")

# ╔═╡ 413dfa90-2449-4c60-a08b-c00a314bb9d4
tchanã(q22, "d)")

# ╔═╡ 2e02a0fe-192c-42c9-b20e-672ad83041bd
tchanã(q23, "a)")

# ╔═╡ a414d369-d2b3-4134-84b9-2e6ac26f9e9a
tchanã(q24,"b)")

# ╔═╡ f0f6988f-b590-4ab4-b088-7a67ad1af196
tchanã(q25, "b)")

# ╔═╡ f0ba7797-0129-4e6e-9875-088d5e276fad
tchanã(q26, "c)")

# ╔═╡ 355de7c5-d5c4-43ae-88eb-d3fb38a63e3e
tchanã(q27, "a)")

# ╔═╡ e511500d-1830-4ef0-8824-fe08b2308dc3
tchanã(q28, "c)")

# ╔═╡ 247238b8-aef9-4a96-8892-590b32f822d5
tchanã(q29, "b)")

# ╔═╡ f441278d-8b44-4fb2-a061-ee6360088177
tchanã(q30, "b)")

# ╔═╡ 9b7a97dd-0d7b-4414-b41c-530bd05ece12
tchanã(q31, "d)")

# ╔═╡ bb0849ae-c1f1-4cbe-92aa-8291039cd088
tchanã(q32, "c)")

# ╔═╡ 66088733-aeda-4580-99e5-17cf027c9efb
tchanã(q33, "d)")

# ╔═╡ 27009076-3654-4513-ae66-375c3c03296d
tchanã(q34, "a)")

# ╔═╡ 1f50d22d-db78-4382-8708-61614f576f27
tchanã(q35, "a)")

# ╔═╡ 47283948-ecbd-4bf9-9695-a59dd21fafa8
tchanã(q36, "a)")

# ╔═╡ 98ef493e-8e7b-4edc-9470-06d6d8f9c6a4
tchanã(q37, "c)")

# ╔═╡ ddaec933-a0f1-45b2-91cd-40c9d1308818
tchanã(q38, "a)")

# ╔═╡ 3f83b209-e81c-4e7e-86c3-3076219212cb
tchanã(q39, "d)")

# ╔═╡ 4688f4e1-de7b-44d0-94ed-26e864ba2f34
tchanã(q40, "a)")

# ╔═╡ 00000000-0000-0000-0000-000000000001
PLUTO_PROJECT_TOML_CONTENTS = """
[deps]
CSV = "336ed68f-0bac-5ca0-87d4-7b16caf5d00b"
DataFrames = "a93c6f00-e57d-5684-b7b6-d8193f3e46c0"
Dates = "ade2ca70-3891-5945-98fb-dc099432e06a"
HypertextLiteral = "ac1192a8-f4b3-4bfe-ba22-af5b92cd3ab2"
NLsolve = "2774e3e8-f4cf-5e23-947b-6d7e65073b56"
PeriodicalDates = "276e7ca9-e0d7-440b-97bc-a6ae82f545b1"
PlotlyBase = "a03496cd-edff-5a9b-9e67-9cda94a718b5"
PlutoTeachingTools = "661c6b06-c737-4d37-b85c-46df65de6f69"
PlutoUI = "7f904dfe-b85e-4ff6-b463-dae2292396a8"
StatsBase = "2913bbd2-ae8a-5f71-8c99-4fb6c76f3a91"

[compat]
CSV = "~0.10.9"
DataFrames = "~1.5.0"
HypertextLiteral = "~0.9.4"
NLsolve = "~4.5.1"
PeriodicalDates = "~2.0.0"
PlotlyBase = "~0.8.19"
PlutoTeachingTools = "~0.2.6"
PlutoUI = "~0.7.50"
StatsBase = "~0.33.21"
"""

# ╔═╡ 00000000-0000-0000-0000-000000000002
PLUTO_MANIFEST_TOML_CONTENTS = """
# This file is machine-generated - editing it directly is not advised

julia_version = "1.9.3"
manifest_format = "2.0"
project_hash = "f88dc0d3148f9d4cd8e6552f520f505b5be27453"

[[deps.AbstractPlutoDingetjes]]
deps = ["Pkg"]
git-tree-sha1 = "91bd53c39b9cbfb5ef4b015e8b582d344532bd0a"
uuid = "6e696c72-6542-2067-7265-42206c756150"
version = "1.2.0"

[[deps.Adapt]]
deps = ["LinearAlgebra", "Requires"]
git-tree-sha1 = "76289dc51920fdc6e0013c872ba9551d54961c24"
uuid = "79e6a3ab-5dfb-504d-930d-738a2a938a0e"
version = "3.6.2"

    [deps.Adapt.extensions]
    AdaptStaticArraysExt = "StaticArrays"

    [deps.Adapt.weakdeps]
    StaticArrays = "90137ffa-7385-5640-81b9-e52037218182"

[[deps.ArgTools]]
uuid = "0dad84c5-d112-42e6-8d28-ef12dabb789f"
version = "1.1.1"

[[deps.ArrayInterface]]
deps = ["Adapt", "LinearAlgebra", "Requires", "SparseArrays", "SuiteSparse"]
git-tree-sha1 = "f83ec24f76d4c8f525099b2ac475fc098138ec31"
uuid = "4fba245c-0d91-5ea0-9b3e-6abc04ee57a9"
version = "7.4.11"

    [deps.ArrayInterface.extensions]
    ArrayInterfaceBandedMatricesExt = "BandedMatrices"
    ArrayInterfaceBlockBandedMatricesExt = "BlockBandedMatrices"
    ArrayInterfaceCUDAExt = "CUDA"
    ArrayInterfaceGPUArraysCoreExt = "GPUArraysCore"
    ArrayInterfaceStaticArraysCoreExt = "StaticArraysCore"
    ArrayInterfaceTrackerExt = "Tracker"

    [deps.ArrayInterface.weakdeps]
    BandedMatrices = "aae01518-5342-5314-be14-df237901396f"
    BlockBandedMatrices = "ffab5731-97b5-5995-9138-79e8c1846df0"
    CUDA = "052768ef-5323-5732-b1bb-66c8b64840ba"
    GPUArraysCore = "46192b85-c4d5-4398-a991-12ede77f4527"
    StaticArraysCore = "1e83bf80-4336-4d27-bf5d-d5a4f845583c"
    Tracker = "9f7883ad-71c0-57eb-9f7f-b5c9e6d3789c"

[[deps.Artifacts]]
uuid = "56f22d72-fd6d-98f1-02f0-08ddc0907c33"

[[deps.Base64]]
uuid = "2a0f44e3-6c83-55bd-87e4-b1978d98bd5f"

[[deps.CSV]]
deps = ["CodecZlib", "Dates", "FilePathsBase", "InlineStrings", "Mmap", "Parsers", "PooledArrays", "PrecompileTools", "SentinelArrays", "Tables", "Unicode", "WeakRefStrings", "WorkerUtilities"]
git-tree-sha1 = "44dbf560808d49041989b8a96cae4cffbeb7966a"
uuid = "336ed68f-0bac-5ca0-87d4-7b16caf5d00b"
version = "0.10.11"

[[deps.CodeTracking]]
deps = ["InteractiveUtils", "UUIDs"]
git-tree-sha1 = "a1296f0fe01a4c3f9bf0dc2934efbf4416f5db31"
uuid = "da1fd8a2-8d9e-5ec2-8556-3022fb5608a2"
version = "1.3.4"

[[deps.CodecZlib]]
deps = ["TranscodingStreams", "Zlib_jll"]
git-tree-sha1 = "02aa26a4cf76381be7f66e020a3eddeb27b0a092"
uuid = "944b1d66-785c-5afd-91f1-9de20f533193"
version = "0.7.2"

[[deps.ColorSchemes]]
deps = ["ColorTypes", "ColorVectorSpace", "Colors", "FixedPointNumbers", "PrecompileTools", "Random"]
git-tree-sha1 = "d9a8f86737b665e15a9641ecbac64deef9ce6724"
uuid = "35d6a980-a343-548e-a6ea-1d62b119f2f4"
version = "3.23.0"

[[deps.ColorTypes]]
deps = ["FixedPointNumbers", "Random"]
git-tree-sha1 = "eb7f0f8307f71fac7c606984ea5fb2817275d6e4"
uuid = "3da002f7-5984-5a60-b8a6-cbb66c0b333f"
version = "0.11.4"

[[deps.ColorVectorSpace]]
deps = ["ColorTypes", "FixedPointNumbers", "LinearAlgebra", "Requires", "Statistics", "TensorCore"]
git-tree-sha1 = "a1f44953f2382ebb937d60dafbe2deea4bd23249"
uuid = "c3611d14-8923-5661-9e6a-0046d554d3a4"
version = "0.10.0"
weakdeps = ["SpecialFunctions"]

    [deps.ColorVectorSpace.extensions]
    SpecialFunctionsExt = "SpecialFunctions"

[[deps.Colors]]
deps = ["ColorTypes", "FixedPointNumbers", "Reexport"]
git-tree-sha1 = "fc08e5930ee9a4e03f84bfb5211cb54e7769758a"
uuid = "5ae59095-9a9b-59fe-a467-6f913c188581"
version = "0.12.10"

[[deps.CommonSubexpressions]]
deps = ["MacroTools", "Test"]
git-tree-sha1 = "7b8a93dba8af7e3b42fecabf646260105ac373f7"
uuid = "bbf7d656-a473-5ed7-a52c-81e309532950"
version = "0.3.0"

[[deps.Compat]]
deps = ["UUIDs"]
git-tree-sha1 = "e460f044ca8b99be31d35fe54fc33a5c33dd8ed7"
uuid = "34da2185-b29b-5c13-b0c7-acf172513d20"
version = "4.9.0"
weakdeps = ["Dates", "LinearAlgebra"]

    [deps.Compat.extensions]
    CompatLinearAlgebraExt = "LinearAlgebra"

[[deps.CompilerSupportLibraries_jll]]
deps = ["Artifacts", "Libdl"]
uuid = "e66e0078-7015-5450-92f7-15fbd957f2ae"
version = "1.0.5+0"

[[deps.ConstructionBase]]
deps = ["LinearAlgebra"]
git-tree-sha1 = "c53fc348ca4d40d7b371e71fd52251839080cbc9"
uuid = "187b0558-2788-49d3-abe0-74a17ed4e7c9"
version = "1.5.4"

    [deps.ConstructionBase.extensions]
    ConstructionBaseIntervalSetsExt = "IntervalSets"
    ConstructionBaseStaticArraysExt = "StaticArrays"

    [deps.ConstructionBase.weakdeps]
    IntervalSets = "8197267c-284f-5f27-9208-e0e47529a953"
    StaticArrays = "90137ffa-7385-5640-81b9-e52037218182"

[[deps.Crayons]]
git-tree-sha1 = "249fe38abf76d48563e2f4556bebd215aa317e15"
uuid = "a8cc5b0e-0ffa-5ad4-8c14-923d3ee1735f"
version = "4.1.1"

[[deps.DataAPI]]
git-tree-sha1 = "8da84edb865b0b5b0100c0666a9bc9a0b71c553c"
uuid = "9a962f9c-6df0-11e9-0e5d-c546b8b5ee8a"
version = "1.15.0"

[[deps.DataFrames]]
deps = ["Compat", "DataAPI", "Future", "InlineStrings", "InvertedIndices", "IteratorInterfaceExtensions", "LinearAlgebra", "Markdown", "Missings", "PooledArrays", "PrettyTables", "Printf", "REPL", "Random", "Reexport", "SentinelArrays", "SnoopPrecompile", "SortingAlgorithms", "Statistics", "TableTraits", "Tables", "Unicode"]
git-tree-sha1 = "aa51303df86f8626a962fccb878430cdb0a97eee"
uuid = "a93c6f00-e57d-5684-b7b6-d8193f3e46c0"
version = "1.5.0"

[[deps.DataStructures]]
deps = ["Compat", "InteractiveUtils", "OrderedCollections"]
git-tree-sha1 = "3dbd312d370723b6bb43ba9d02fc36abade4518d"
uuid = "864edb3b-99cc-5e75-8d2d-829cb0a9cfe8"
version = "0.18.15"

[[deps.DataValueInterfaces]]
git-tree-sha1 = "bfc1187b79289637fa0ef6d4436ebdfe6905cbd6"
uuid = "e2d170a0-9d28-54be-80f0-106bbe20a464"
version = "1.0.0"

[[deps.Dates]]
deps = ["Printf"]
uuid = "ade2ca70-3891-5945-98fb-dc099432e06a"

[[deps.DelimitedFiles]]
deps = ["Mmap"]
git-tree-sha1 = "9e2f36d3c96a820c678f2f1f1782582fcf685bae"
uuid = "8bb1440f-4735-579b-a4ab-409b98df4dab"
version = "1.9.1"

[[deps.DiffResults]]
deps = ["StaticArraysCore"]
git-tree-sha1 = "782dd5f4561f5d267313f23853baaaa4c52ea621"
uuid = "163ba53b-c6d8-5494-b064-1a9d43ac40c5"
version = "1.1.0"

[[deps.DiffRules]]
deps = ["IrrationalConstants", "LogExpFunctions", "NaNMath", "Random", "SpecialFunctions"]
git-tree-sha1 = "23163d55f885173722d1e4cf0f6110cdbaf7e272"
uuid = "b552c78f-8df3-52c6-915a-8e097449b14b"
version = "1.15.1"

[[deps.Distances]]
deps = ["LinearAlgebra", "Statistics", "StatsAPI"]
git-tree-sha1 = "5225c965635d8c21168e32a12954675e7bea1151"
uuid = "b4f34e82-e78d-54a5-968a-f98e89d6e8f7"
version = "0.10.10"

    [deps.Distances.extensions]
    DistancesChainRulesCoreExt = "ChainRulesCore"
    DistancesSparseArraysExt = "SparseArrays"

    [deps.Distances.weakdeps]
    ChainRulesCore = "d360d2e6-b24c-11e9-a2a3-2a2ae2dbcce4"
    SparseArrays = "2f01184e-e22b-5df5-ae63-d93ebab69eaf"

[[deps.Distributed]]
deps = ["Random", "Serialization", "Sockets"]
uuid = "8ba89e20-285c-5b6f-9357-94700520ee1b"

[[deps.DocStringExtensions]]
deps = ["LibGit2"]
git-tree-sha1 = "2fb1e02f2b635d0845df5d7c167fec4dd739b00d"
uuid = "ffbed154-4ef7-542d-bbb7-c09d3a79fcae"
version = "0.9.3"

[[deps.Downloads]]
deps = ["ArgTools", "FileWatching", "LibCURL", "NetworkOptions"]
uuid = "f43a241f-c20a-4ad4-852c-f6b1247861c6"
version = "1.6.0"

[[deps.FilePathsBase]]
deps = ["Compat", "Dates", "Mmap", "Printf", "Test", "UUIDs"]
git-tree-sha1 = "e27c4ebe80e8699540f2d6c805cc12203b614f12"
uuid = "48062228-2e41-5def-b9a4-89aafe57970f"
version = "0.9.20"

[[deps.FileWatching]]
uuid = "7b1f6079-737a-58dc-b8bc-7a2ca5c1b5ee"

[[deps.FiniteDiff]]
deps = ["ArrayInterface", "LinearAlgebra", "Requires", "Setfield", "SparseArrays"]
git-tree-sha1 = "c6e4a1fbe73b31a3dea94b1da449503b8830c306"
uuid = "6a86dc24-6348-571c-b903-95158fe2bd41"
version = "2.21.1"

    [deps.FiniteDiff.extensions]
    FiniteDiffBandedMatricesExt = "BandedMatrices"
    FiniteDiffBlockBandedMatricesExt = "BlockBandedMatrices"
    FiniteDiffStaticArraysExt = "StaticArrays"

    [deps.FiniteDiff.weakdeps]
    BandedMatrices = "aae01518-5342-5314-be14-df237901396f"
    BlockBandedMatrices = "ffab5731-97b5-5995-9138-79e8c1846df0"
    StaticArrays = "90137ffa-7385-5640-81b9-e52037218182"

[[deps.FixedPointNumbers]]
deps = ["Statistics"]
git-tree-sha1 = "335bfdceacc84c5cdf16aadc768aa5ddfc5383cc"
uuid = "53c48c17-4a7d-5ca2-90c5-79b7896eea93"
version = "0.8.4"

[[deps.Formatting]]
deps = ["Printf"]
git-tree-sha1 = "8339d61043228fdd3eb658d86c926cb282ae72a8"
uuid = "59287772-0a20-5a39-b81b-1366585eb4c0"
version = "0.4.2"

[[deps.ForwardDiff]]
deps = ["CommonSubexpressions", "DiffResults", "DiffRules", "LinearAlgebra", "LogExpFunctions", "NaNMath", "Preferences", "Printf", "Random", "SpecialFunctions"]
git-tree-sha1 = "cf0fe81336da9fb90944683b8c41984b08793dad"
uuid = "f6369f11-7733-5829-9624-2563aa707210"
version = "0.10.36"

    [deps.ForwardDiff.extensions]
    ForwardDiffStaticArraysExt = "StaticArrays"

    [deps.ForwardDiff.weakdeps]
    StaticArrays = "90137ffa-7385-5640-81b9-e52037218182"

[[deps.Future]]
deps = ["Random"]
uuid = "9fa8497b-333b-5362-9e8d-4d0656e87820"

[[deps.Hyperscript]]
deps = ["Test"]
git-tree-sha1 = "8d511d5b81240fc8e6802386302675bdf47737b9"
uuid = "47d2ed2b-36de-50cf-bf87-49c2cf4b8b91"
version = "0.0.4"

[[deps.HypertextLiteral]]
deps = ["Tricks"]
git-tree-sha1 = "c47c5fa4c5308f27ccaac35504858d8914e102f9"
uuid = "ac1192a8-f4b3-4bfe-ba22-af5b92cd3ab2"
version = "0.9.4"

[[deps.IOCapture]]
deps = ["Logging", "Random"]
git-tree-sha1 = "d75853a0bdbfb1ac815478bacd89cd27b550ace6"
uuid = "b5f81e59-6552-4d32-b1f0-c071b021bf89"
version = "0.2.3"

[[deps.InlineStrings]]
deps = ["Parsers"]
git-tree-sha1 = "9cc2baf75c6d09f9da536ddf58eb2f29dedaf461"
uuid = "842dd82b-1e85-43dc-bf29-5d0ee9dffc48"
version = "1.4.0"

[[deps.InteractiveUtils]]
deps = ["Markdown"]
uuid = "b77e0a4c-d291-57a0-90e8-8db25a27a240"

[[deps.InvertedIndices]]
git-tree-sha1 = "0dc7b50b8d436461be01300fd8cd45aa0274b038"
uuid = "41ab1584-1d38-5bbf-9106-f11c6c58b48f"
version = "1.3.0"

[[deps.IrrationalConstants]]
git-tree-sha1 = "630b497eafcc20001bba38a4651b327dcfc491d2"
uuid = "92d709cd-6900-40b7-9082-c6be49f344b6"
version = "0.2.2"

[[deps.IteratorInterfaceExtensions]]
git-tree-sha1 = "a3f24677c21f5bbe9d2a714f95dcd58337fb2856"
uuid = "82899510-4779-5014-852e-03e436cf321d"
version = "1.0.0"

[[deps.JLLWrappers]]
deps = ["Artifacts", "Preferences"]
git-tree-sha1 = "7e5d6779a1e09a36db2a7b6cff50942a0a7d0fca"
uuid = "692b3bcd-3c85-4b1f-b108-f13ce0eb3210"
version = "1.5.0"

[[deps.JSON]]
deps = ["Dates", "Mmap", "Parsers", "Unicode"]
git-tree-sha1 = "31e996f0a15c7b280ba9f76636b3ff9e2ae58c9a"
uuid = "682c06a0-de6a-54ab-a142-c8b1cf79cde6"
version = "0.21.4"

[[deps.JuliaInterpreter]]
deps = ["CodeTracking", "InteractiveUtils", "Random", "UUIDs"]
git-tree-sha1 = "81dc6aefcbe7421bd62cb6ca0e700779330acff8"
uuid = "aa1ae85d-cabe-5617-a682-6adf51b2e16a"
version = "0.9.25"

[[deps.LaTeXStrings]]
git-tree-sha1 = "f2355693d6778a178ade15952b7ac47a4ff97996"
uuid = "b964fa9f-0449-5b57-a5c2-d3ea65f4040f"
version = "1.3.0"

[[deps.Latexify]]
deps = ["Formatting", "InteractiveUtils", "LaTeXStrings", "MacroTools", "Markdown", "OrderedCollections", "Printf", "Requires"]
git-tree-sha1 = "f428ae552340899a935973270b8d98e5a31c49fe"
uuid = "23fbe1c1-3f47-55db-b15f-69d7ec21a316"
version = "0.16.1"

    [deps.Latexify.extensions]
    DataFramesExt = "DataFrames"
    SymEngineExt = "SymEngine"

    [deps.Latexify.weakdeps]
    DataFrames = "a93c6f00-e57d-5684-b7b6-d8193f3e46c0"
    SymEngine = "123dc426-2d89-5057-bbad-38513e3affd8"

[[deps.LibCURL]]
deps = ["LibCURL_jll", "MozillaCACerts_jll"]
uuid = "b27032c2-a3e7-50c8-80cd-2d36dbcbfd21"
version = "0.6.3"

[[deps.LibCURL_jll]]
deps = ["Artifacts", "LibSSH2_jll", "Libdl", "MbedTLS_jll", "Zlib_jll", "nghttp2_jll"]
uuid = "deac9b47-8bc7-5906-a0fe-35ac56dc84c0"
version = "7.84.0+0"

[[deps.LibGit2]]
deps = ["Base64", "NetworkOptions", "Printf", "SHA"]
uuid = "76f85450-5226-5b5a-8eaa-529ad045b433"

[[deps.LibSSH2_jll]]
deps = ["Artifacts", "Libdl", "MbedTLS_jll"]
uuid = "29816b5a-b9ab-546f-933c-edad1886dfa8"
version = "1.10.2+0"

[[deps.Libdl]]
uuid = "8f399da3-3557-5675-b5ff-fb832c97cbdb"

[[deps.LineSearches]]
deps = ["LinearAlgebra", "NLSolversBase", "NaNMath", "Parameters", "Printf"]
git-tree-sha1 = "7bbea35cec17305fc70a0e5b4641477dc0789d9d"
uuid = "d3d80556-e9d4-5f37-9878-2ab0fcc64255"
version = "7.2.0"

[[deps.LinearAlgebra]]
deps = ["Libdl", "OpenBLAS_jll", "libblastrampoline_jll"]
uuid = "37e2e46d-f89d-539d-b4ee-838fcccc9c8e"

[[deps.LogExpFunctions]]
deps = ["DocStringExtensions", "IrrationalConstants", "LinearAlgebra"]
git-tree-sha1 = "7d6dd4e9212aebaeed356de34ccf262a3cd415aa"
uuid = "2ab3a3ac-af41-5b50-aa03-7779005ae688"
version = "0.3.26"

    [deps.LogExpFunctions.extensions]
    LogExpFunctionsChainRulesCoreExt = "ChainRulesCore"
    LogExpFunctionsChangesOfVariablesExt = "ChangesOfVariables"
    LogExpFunctionsInverseFunctionsExt = "InverseFunctions"

    [deps.LogExpFunctions.weakdeps]
    ChainRulesCore = "d360d2e6-b24c-11e9-a2a3-2a2ae2dbcce4"
    ChangesOfVariables = "9e997f8a-9a97-42d5-a9f1-ce6bfc15e2c0"
    InverseFunctions = "3587e190-3f89-42d0-90ee-14403ec27112"

[[deps.Logging]]
uuid = "56ddb016-857b-54e1-b83d-db4d58db5568"

[[deps.LoweredCodeUtils]]
deps = ["JuliaInterpreter"]
git-tree-sha1 = "60168780555f3e663c536500aa790b6368adc02a"
uuid = "6f1432cf-f94c-5a45-995e-cdbf5db27b0b"
version = "2.3.0"

[[deps.MIMEs]]
git-tree-sha1 = "65f28ad4b594aebe22157d6fac869786a255b7eb"
uuid = "6c6e2e6c-3030-632d-7369-2d6c69616d65"
version = "0.1.4"

[[deps.MacroTools]]
deps = ["Markdown", "Random"]
git-tree-sha1 = "9ee1618cbf5240e6d4e0371d6f24065083f60c48"
uuid = "1914dd2f-81c6-5fcd-8719-6d5c9610ff09"
version = "0.5.11"

[[deps.Markdown]]
deps = ["Base64"]
uuid = "d6f4376e-aef5-505a-96c1-9c027394607a"

[[deps.MbedTLS_jll]]
deps = ["Artifacts", "Libdl"]
uuid = "c8ffd9c3-330d-5841-b78e-0817d7145fa1"
version = "2.28.2+0"

[[deps.Missings]]
deps = ["DataAPI"]
git-tree-sha1 = "f66bdc5de519e8f8ae43bdc598782d35a25b1272"
uuid = "e1d29d7a-bbdc-5cf2-9ac0-f12de2c33e28"
version = "1.1.0"

[[deps.Mmap]]
uuid = "a63ad114-7e13-5084-954f-fe012c677804"

[[deps.MozillaCACerts_jll]]
uuid = "14a3606d-f60d-562e-9121-12d972cd8159"
version = "2022.10.11"

[[deps.NLSolversBase]]
deps = ["DiffResults", "Distributed", "FiniteDiff", "ForwardDiff"]
git-tree-sha1 = "a0b464d183da839699f4c79e7606d9d186ec172c"
uuid = "d41bc354-129a-5804-8e4c-c37616107c6c"
version = "7.8.3"

[[deps.NLsolve]]
deps = ["Distances", "LineSearches", "LinearAlgebra", "NLSolversBase", "Printf", "Reexport"]
git-tree-sha1 = "019f12e9a1a7880459d0173c182e6a99365d7ac1"
uuid = "2774e3e8-f4cf-5e23-947b-6d7e65073b56"
version = "4.5.1"

[[deps.NaNMath]]
deps = ["OpenLibm_jll"]
git-tree-sha1 = "0877504529a3e5c3343c6f8b4c0381e57e4387e4"
uuid = "77ba4419-2d1f-58cd-9bb1-8ffee604a2e3"
version = "1.0.2"

[[deps.NetworkOptions]]
uuid = "ca575930-c2e3-43a9-ace4-1e988b2c1908"
version = "1.2.0"

[[deps.OpenBLAS_jll]]
deps = ["Artifacts", "CompilerSupportLibraries_jll", "Libdl"]
uuid = "4536629a-c528-5b80-bd46-f80d51c5b363"
version = "0.3.21+4"

[[deps.OpenLibm_jll]]
deps = ["Artifacts", "Libdl"]
uuid = "05823500-19ac-5b8b-9628-191a04bc5112"
version = "0.8.1+0"

[[deps.OpenSpecFun_jll]]
deps = ["Artifacts", "CompilerSupportLibraries_jll", "JLLWrappers", "Libdl", "Pkg"]
git-tree-sha1 = "13652491f6856acfd2db29360e1bbcd4565d04f1"
uuid = "efe28fd5-8261-553b-a9e1-b2916fc3738e"
version = "0.5.5+0"

[[deps.OrderedCollections]]
git-tree-sha1 = "2e73fe17cac3c62ad1aebe70d44c963c3cfdc3e3"
uuid = "bac558e1-5e72-5ebc-8fee-abe8a469f55d"
version = "1.6.2"

[[deps.Parameters]]
deps = ["OrderedCollections", "UnPack"]
git-tree-sha1 = "34c0e9ad262e5f7fc75b10a9952ca7692cfc5fbe"
uuid = "d96e819e-fc66-5662-9728-84c9c7592b0a"
version = "0.12.3"

[[deps.Parsers]]
deps = ["Dates", "PrecompileTools", "UUIDs"]
git-tree-sha1 = "716e24b21538abc91f6205fd1d8363f39b442851"
uuid = "69de0a69-1ddd-5017-9359-2bf0b02dc9f0"
version = "2.7.2"

[[deps.PeriodicalDates]]
deps = ["Dates", "Printf", "RecipesBase"]
git-tree-sha1 = "e616941f8093e50a373e7d51875143213f82eca4"
uuid = "276e7ca9-e0d7-440b-97bc-a6ae82f545b1"
version = "2.0.0"

[[deps.Pkg]]
deps = ["Artifacts", "Dates", "Downloads", "FileWatching", "LibGit2", "Libdl", "Logging", "Markdown", "Printf", "REPL", "Random", "SHA", "Serialization", "TOML", "Tar", "UUIDs", "p7zip_jll"]
uuid = "44cfe95a-1eb2-52ea-b672-e2afdf69b78f"
version = "1.9.2"

[[deps.PlotlyBase]]
deps = ["ColorSchemes", "Dates", "DelimitedFiles", "DocStringExtensions", "JSON", "LaTeXStrings", "Logging", "Parameters", "Pkg", "REPL", "Requires", "Statistics", "UUIDs"]
git-tree-sha1 = "56baf69781fc5e61607c3e46227ab17f7040ffa2"
uuid = "a03496cd-edff-5a9b-9e67-9cda94a718b5"
version = "0.8.19"

[[deps.PlutoHooks]]
deps = ["InteractiveUtils", "Markdown", "UUIDs"]
git-tree-sha1 = "072cdf20c9b0507fdd977d7d246d90030609674b"
uuid = "0ff47ea0-7a50-410d-8455-4348d5de0774"
version = "0.0.5"

[[deps.PlutoLinks]]
deps = ["FileWatching", "InteractiveUtils", "Markdown", "PlutoHooks", "Revise", "UUIDs"]
git-tree-sha1 = "8f5fa7056e6dcfb23ac5211de38e6c03f6367794"
uuid = "0ff47ea0-7a50-410d-8455-4348d5de0420"
version = "0.1.6"

[[deps.PlutoTeachingTools]]
deps = ["Downloads", "HypertextLiteral", "LaTeXStrings", "Latexify", "Markdown", "PlutoLinks", "PlutoUI", "Random"]
git-tree-sha1 = "542de5acb35585afcf202a6d3361b430bc1c3fbd"
uuid = "661c6b06-c737-4d37-b85c-46df65de6f69"
version = "0.2.13"

[[deps.PlutoUI]]
deps = ["AbstractPlutoDingetjes", "Base64", "ColorTypes", "Dates", "FixedPointNumbers", "Hyperscript", "HypertextLiteral", "IOCapture", "InteractiveUtils", "JSON", "Logging", "MIMEs", "Markdown", "Random", "Reexport", "URIs", "UUIDs"]
git-tree-sha1 = "e47cd150dbe0443c3a3651bc5b9cbd5576ab75b7"
uuid = "7f904dfe-b85e-4ff6-b463-dae2292396a8"
version = "0.7.52"

[[deps.PooledArrays]]
deps = ["DataAPI", "Future"]
git-tree-sha1 = "a6062fe4063cdafe78f4a0a81cfffb89721b30e7"
uuid = "2dfb63ee-cc39-5dd5-95bd-886bf059d720"
version = "1.4.2"

[[deps.PrecompileTools]]
deps = ["Preferences"]
git-tree-sha1 = "03b4c25b43cb84cee5c90aa9b5ea0a78fd848d2f"
uuid = "aea7be01-6a6a-4083-8856-8a6e6704d82a"
version = "1.2.0"

[[deps.Preferences]]
deps = ["TOML"]
git-tree-sha1 = "7eb1686b4f04b82f96ed7a4ea5890a4f0c7a09f1"
uuid = "21216c6a-2e73-6563-6e65-726566657250"
version = "1.4.0"

[[deps.PrettyTables]]
deps = ["Crayons", "LaTeXStrings", "Markdown", "Printf", "Reexport", "StringManipulation", "Tables"]
git-tree-sha1 = "ee094908d720185ddbdc58dbe0c1cbe35453ec7a"
uuid = "08abe8d2-0d0c-5749-adfa-8a2ac140af0d"
version = "2.2.7"

[[deps.Printf]]
deps = ["Unicode"]
uuid = "de0858da-6303-5e67-8744-51eddeeeb8d7"

[[deps.REPL]]
deps = ["InteractiveUtils", "Markdown", "Sockets", "Unicode"]
uuid = "3fa0cd96-eef1-5676-8a61-b3b8758bbffb"

[[deps.Random]]
deps = ["SHA", "Serialization"]
uuid = "9a3f8284-a2c9-5f02-9a11-845980a1fd5c"

[[deps.RecipesBase]]
deps = ["PrecompileTools"]
git-tree-sha1 = "5c3d09cc4f31f5fc6af001c250bf1278733100ff"
uuid = "3cdcf5f2-1ef4-517c-9805-6587b60abb01"
version = "1.3.4"

[[deps.Reexport]]
git-tree-sha1 = "45e428421666073eab6f2da5c9d310d99bb12f9b"
uuid = "189a3867-3050-52da-a836-e630ba90ab69"
version = "1.2.2"

[[deps.Requires]]
deps = ["UUIDs"]
git-tree-sha1 = "838a3a4188e2ded87a4f9f184b4b0d78a1e91cb7"
uuid = "ae029012-a4dd-5104-9daa-d747884805df"
version = "1.3.0"

[[deps.Revise]]
deps = ["CodeTracking", "Distributed", "FileWatching", "JuliaInterpreter", "LibGit2", "LoweredCodeUtils", "OrderedCollections", "Pkg", "REPL", "Requires", "UUIDs", "Unicode"]
git-tree-sha1 = "1e597b93700fa4045d7189afa7c004e0584ea548"
uuid = "295af30f-e4ad-537b-8983-00126c2a3abe"
version = "3.5.3"

[[deps.SHA]]
uuid = "ea8e919c-243c-51af-8825-aaa63cd721ce"
version = "0.7.0"

[[deps.SentinelArrays]]
deps = ["Dates", "Random"]
git-tree-sha1 = "04bdff0b09c65ff3e06a05e3eb7b120223da3d39"
uuid = "91c51154-3ec4-41a3-a24f-3f23e20d615c"
version = "1.4.0"

[[deps.Serialization]]
uuid = "9e88b42a-f829-5b0c-bbe9-9e923198166b"

[[deps.Setfield]]
deps = ["ConstructionBase", "Future", "MacroTools", "StaticArraysCore"]
git-tree-sha1 = "e2cc6d8c88613c05e1defb55170bf5ff211fbeac"
uuid = "efcf1570-3423-57d1-acb7-fd33fddbac46"
version = "1.1.1"

[[deps.SnoopPrecompile]]
deps = ["Preferences"]
git-tree-sha1 = "e760a70afdcd461cf01a575947738d359234665c"
uuid = "66db9d55-30c0-4569-8b51-7e840670fc0c"
version = "1.0.3"

[[deps.Sockets]]
uuid = "6462fe0b-24de-5631-8697-dd941f90decc"

[[deps.SortingAlgorithms]]
deps = ["DataStructures"]
git-tree-sha1 = "c60ec5c62180f27efea3ba2908480f8055e17cee"
uuid = "a2af1166-a08f-5f64-846c-94a0d3cef48c"
version = "1.1.1"

[[deps.SparseArrays]]
deps = ["Libdl", "LinearAlgebra", "Random", "Serialization", "SuiteSparse_jll"]
uuid = "2f01184e-e22b-5df5-ae63-d93ebab69eaf"

[[deps.SpecialFunctions]]
deps = ["IrrationalConstants", "LogExpFunctions", "OpenLibm_jll", "OpenSpecFun_jll"]
git-tree-sha1 = "e2cfc4012a19088254b3950b85c3c1d8882d864d"
uuid = "276daf66-3868-5448-9aa4-cd146d93841b"
version = "2.3.1"

    [deps.SpecialFunctions.extensions]
    SpecialFunctionsChainRulesCoreExt = "ChainRulesCore"

    [deps.SpecialFunctions.weakdeps]
    ChainRulesCore = "d360d2e6-b24c-11e9-a2a3-2a2ae2dbcce4"

[[deps.StaticArraysCore]]
git-tree-sha1 = "36b3d696ce6366023a0ea192b4cd442268995a0d"
uuid = "1e83bf80-4336-4d27-bf5d-d5a4f845583c"
version = "1.4.2"

[[deps.Statistics]]
deps = ["LinearAlgebra", "SparseArrays"]
uuid = "10745b16-79ce-11e8-11f9-7d13ad32a3b2"
version = "1.9.0"

[[deps.StatsAPI]]
deps = ["LinearAlgebra"]
git-tree-sha1 = "45a7769a04a3cf80da1c1c7c60caf932e6f4c9f7"
uuid = "82ae8749-77ed-4fe6-ae5f-f523153014b0"
version = "1.6.0"

[[deps.StatsBase]]
deps = ["DataAPI", "DataStructures", "LinearAlgebra", "LogExpFunctions", "Missings", "Printf", "Random", "SortingAlgorithms", "SparseArrays", "Statistics", "StatsAPI"]
git-tree-sha1 = "d1bf48bfcc554a3761a133fe3a9bb01488e06916"
uuid = "2913bbd2-ae8a-5f71-8c99-4fb6c76f3a91"
version = "0.33.21"

[[deps.StringManipulation]]
git-tree-sha1 = "46da2434b41f41ac3594ee9816ce5541c6096123"
uuid = "892a3eda-7b42-436c-8928-eab12a02cf0e"
version = "0.3.0"

[[deps.SuiteSparse]]
deps = ["Libdl", "LinearAlgebra", "Serialization", "SparseArrays"]
uuid = "4607b0f0-06f3-5cda-b6b1-a6196a1729e9"

[[deps.SuiteSparse_jll]]
deps = ["Artifacts", "Libdl", "Pkg", "libblastrampoline_jll"]
uuid = "bea87d4a-7f5b-5778-9afe-8cc45184846c"
version = "5.10.1+6"

[[deps.TOML]]
deps = ["Dates"]
uuid = "fa267f1f-6049-4f14-aa54-33bafae1ed76"
version = "1.0.3"

[[deps.TableTraits]]
deps = ["IteratorInterfaceExtensions"]
git-tree-sha1 = "c06b2f539df1c6efa794486abfb6ed2022561a39"
uuid = "3783bdb8-4a98-5b6b-af9a-565f29a5fe9c"
version = "1.0.1"

[[deps.Tables]]
deps = ["DataAPI", "DataValueInterfaces", "IteratorInterfaceExtensions", "LinearAlgebra", "OrderedCollections", "TableTraits", "Test"]
git-tree-sha1 = "1544b926975372da01227b382066ab70e574a3ec"
uuid = "bd369af6-aec1-5ad0-b16a-f7cc5008161c"
version = "1.10.1"

[[deps.Tar]]
deps = ["ArgTools", "SHA"]
uuid = "a4e569a6-e804-4fa4-b0f3-eef7a1d5b13e"
version = "1.10.0"

[[deps.TensorCore]]
deps = ["LinearAlgebra"]
git-tree-sha1 = "1feb45f88d133a655e001435632f019a9a1bcdb6"
uuid = "62fd8b95-f654-4bbd-a8a5-9c27f68ccd50"
version = "0.1.1"

[[deps.Test]]
deps = ["InteractiveUtils", "Logging", "Random", "Serialization"]
uuid = "8dfed614-e22c-5e08-85e1-65c5234f0b40"

[[deps.TranscodingStreams]]
deps = ["Random", "Test"]
git-tree-sha1 = "9a6ae7ed916312b41236fcef7e0af564ef934769"
uuid = "3bb67fe8-82b1-5028-8e26-92a6c54297fa"
version = "0.9.13"

[[deps.Tricks]]
git-tree-sha1 = "aadb748be58b492045b4f56166b5188aa63ce549"
uuid = "410a4b4d-49e4-4fbc-ab6d-cb71b17b3775"
version = "0.1.7"

[[deps.URIs]]
git-tree-sha1 = "b7a5e99f24892b6824a954199a45e9ffcc1c70f0"
uuid = "5c2747f8-b7ea-4ff2-ba2e-563bfd36b1d4"
version = "1.5.0"

[[deps.UUIDs]]
deps = ["Random", "SHA"]
uuid = "cf7118a7-6976-5b1a-9a39-7adc72f591a4"

[[deps.UnPack]]
git-tree-sha1 = "387c1f73762231e86e0c9c5443ce3b4a0a9a0c2b"
uuid = "3a884ed6-31ef-47d7-9d2a-63182c4928ed"
version = "1.0.2"

[[deps.Unicode]]
uuid = "4ec0a83e-493e-50e2-b9ac-8f72acf5a8f5"

[[deps.WeakRefStrings]]
deps = ["DataAPI", "InlineStrings", "Parsers"]
git-tree-sha1 = "b1be2855ed9ed8eac54e5caff2afcdb442d52c23"
uuid = "ea10d353-3f73-51f8-a26c-33c1cb351aa5"
version = "1.4.2"

[[deps.WorkerUtilities]]
git-tree-sha1 = "cd1659ba0d57b71a464a29e64dbc67cfe83d54e7"
uuid = "76eceee3-57b5-4d4a-8e66-0e911cebbf60"
version = "1.6.1"

[[deps.Zlib_jll]]
deps = ["Libdl"]
uuid = "83775a58-1f1d-513f-b197-d71354ab007a"
version = "1.2.13+0"

[[deps.libblastrampoline_jll]]
deps = ["Artifacts", "Libdl"]
uuid = "8e850b90-86db-534c-a0d3-1478176c7d93"
version = "5.8.0+0"

[[deps.nghttp2_jll]]
deps = ["Artifacts", "Libdl"]
uuid = "8e850ede-7688-5339-a07c-302acd2aaf8d"
version = "1.48.0+0"

[[deps.p7zip_jll]]
deps = ["Artifacts", "Libdl"]
uuid = "3f19e933-33d8-53b3-aaab-bd5110c3b7a0"
version = "17.4.0+0"
"""

# ╔═╡ Cell order:
# ╟─1d00ce38-b7b7-11ed-21b2-23629620f248
# ╟─261f6b80-9e5f-460f-a32b-6c23c2e097a8
# ╟─2d509cd9-2838-48c9-951e-01853b0d2dab
# ╟─f9d4524e-1b2b-4e64-b05a-657475ae6cb4
# ╟─48640531-2ed5-4856-a4fb-bf56617792ea
# ╟─a5d98aa9-ffe5-4f01-8503-df133181eb24
# ╟─5f6cc1d0-fd4a-4f30-a63e-bf2ea6cbe017
# ╟─3b595c53-0a3b-4730-9848-d9cc9361e427
# ╟─26117a53-b772-4d76-85b1-d6594f2a66f7
# ╟─dec4bfa3-6ba7-477b-9747-127b71ffa4ba
# ╟─b38c78f3-96ab-433f-92fe-491fe697ef34
# ╟─c2a1d992-a97a-4523-b795-b2da885d1a4a
# ╟─8a5c4379-c682-4716-9b45-436de5d43ff6
# ╟─a484e20f-7abb-4bf2-ac3c-7a75ac9cd81a
# ╟─15c9273b-23d4-4682-8fa8-e0cbe24031b0
# ╟─833a499e-9563-4008-a246-9e3ab7237307
# ╟─1d871b5d-9713-469e-abce-45fc9b17fb66
# ╟─b31e4f8a-8afb-4c10-94a9-82161da50141
# ╟─f3cd9ffa-1028-4290-9d96-c996a95efbeb
# ╟─d3fe7b23-e2b0-4d38-97af-8d05d838348a
# ╟─1e2aa24b-b8ce-4e8d-ac08-3d249a1ab99e
# ╟─27409c5b-c8da-4135-9c23-227072898a11
# ╟─9954abd1-c0f6-475c-a566-01c5235fb7fd
# ╟─9ba5a92a-b60a-4e16-b7c5-06adf55a1a26
# ╟─a35daac5-655d-4f14-ba9d-515c44ce804f
# ╟─404cab40-7472-45a0-bf29-2666d83fb60d
# ╟─5d7a6a08-d59a-4bf1-8020-2cbd449abcc9
# ╟─74a31c25-c0c7-4ca1-a7a4-b44dc6552c91
# ╟─7e06b93b-367c-4922-9bee-768168c8bada
# ╟─ea3f6fe6-5a61-4f0f-8d36-417bdfce8963
# ╟─3ff3ec3c-559d-4fe3-ba28-444b63936319
# ╠═69ed0a79-57f6-4411-94db-7805b1fdf942
# ╠═8ec6fe02-415b-4994-960f-aec51f3d0620
# ╟─e28a931f-5209-44cb-b93d-d91e7c875611
# ╟─85e56719-918f-435e-a0f4-6996f4a75fab
# ╟─4b4ff1f1-989c-4323-88e9-913e9ff46e4a
# ╟─3ba6660b-b6af-4d44-8f2b-a08f344cdc82
# ╠═c3ca6b71-80b8-45b6-a6d9-3c3f7f498219
# ╠═2a3913df-458d-4ee5-b25b-358bfbaec776
# ╟─d1ddef1f-717a-451d-b6d7-a765edab8ba7
# ╟─a0e5bb9c-0497-434c-b5c4-70d264405a03
# ╟─25296a5f-6083-4cd9-b85c-d338ae761d51
# ╟─e9c43033-18c3-462a-9935-cd3439c15dff
# ╠═dc1cbb96-141a-4d95-99d3-3de916cc89a6
# ╟─3ca2c3bf-4652-455e-ae96-29f15161c3fe
# ╠═b4585a7c-03e9-4279-ac20-293acd4ec2b4
# ╟─54362cca-6b1e-4fa9-b202-bd1518f6a8c9
# ╟─4c56d468-3946-4af4-9a88-e3dae0bc1478
# ╟─0268a10c-6769-4b2a-b4cf-148d4aaeb10c
# ╠═a4ac8f58-7752-430a-b937-eee6c4c8c662
# ╟─a035830d-059a-471d-a758-ce73ee6bfaec
# ╟─4134607c-238a-4c94-932e-ed69fe13e89b
# ╟─43d9f556-f18f-438d-b20e-09a4d6e99b7a
# ╠═d40a4975-d38a-4e76-b5fd-9cfbf1feb2c7
# ╟─82f91003-e90d-4407-9b61-0f7129774686
# ╟─9524aab9-9331-448b-a95a-886df98a68f1
# ╟─5363e9d9-9ca7-4556-b432-7ddaab6229e8
# ╠═2f6833e4-d254-432c-85fa-aa4fff517ee6
# ╟─755e7616-4c9a-4e9a-bfa2-d1bde2ea668c
# ╟─1675a2b4-7526-459b-a989-440e5dfbea27
# ╟─10265196-7cf1-485c-9076-658486f981a5
# ╠═85af9164-07bf-4a10-9162-8668358d3579
# ╟─dec4f528-6cad-42f3-84b8-5a0bca93b561
# ╟─7fae61ee-22d8-462e-b216-6b1dfa427c8e
# ╟─6875e3cb-8bda-4a5d-be91-38584e939f85
# ╠═ea25215f-6df8-40de-ac35-6f8136545e74
# ╟─ce248b19-26df-47ff-8294-11cd903611e3
# ╟─8713c067-8b07-426d-baa9-935d7ef9344e
# ╟─1e0c740c-a4a5-43cc-a9cd-f4e43065ccbd
# ╠═6f5d3464-4058-455c-ab29-48b25a7d198a
# ╟─3e402c14-ef27-43e7-b189-6598fa374949
# ╟─61e87c19-28ca-4ab3-a8d6-22e41471edec
# ╟─ddd0dd83-a842-4f96-b258-f8378f508b0d
# ╠═8c466cb3-a6e0-4c70-bea5-1686e990bb21
# ╟─4d86456c-3c50-490e-b45c-2735cb772a25
# ╟─c27a37a1-6075-4410-8278-2b65cc0415fd
# ╟─c32ca801-ef2a-40b1-bbc4-b7e028872136
# ╠═7e373f54-b88b-4284-9590-decea0eb296f
# ╟─2bb34c87-8859-4ed6-86fc-d2f48296c407
# ╟─8e6113de-6165-4dcf-b8fb-dd8618724f4a
# ╟─cf0b0df7-c855-42ca-b39a-988709298dcc
# ╟─2e58c3b1-f6f8-4bdb-8b64-d47286f98011
# ╟─e0f3a463-2009-4aee-8007-82a19c430ece
# ╟─3687c625-69c7-429b-b1a4-a30d9156ca89
# ╟─db7a69bb-f359-4695-acbd-7065321b4248
# ╟─20c632ce-4e27-40f9-95d7-6e2f1d8140eb
# ╟─213afe7d-dce9-4e2d-bd9a-7eec0b15adce
# ╟─eda5742a-c29b-4ff6-9c35-224ac82cb623
# ╟─009bd98d-cab3-404a-a34d-efe486f7a927
# ╟─0c2ff35a-0781-47d8-9457-e396e41b1449
# ╟─9701c62c-84bc-49cf-9824-cd0247037fee
# ╟─01a5735c-4e85-497f-a6b2-9ccb80cb4977
# ╟─67745071-5308-4657-adf7-85675210d824
# ╟─bfd8f8de-935b-4f35-b548-1a52b08d6676
# ╟─da351fcd-c23d-4879-a17f-2022095a1fc3
# ╟─d4c9f914-6170-4b73-8bc5-65bde9fd66be
# ╟─b50323a4-18ab-4f2d-bbca-40fdc81ede0a
# ╟─b38edbde-eac9-4692-9124-05abffff1c6c
# ╟─6a10ce3b-84b9-4ffa-ab7d-44bd87b0369d
# ╟─413dfa90-2449-4c60-a08b-c00a314bb9d4
# ╟─4ef7feb3-4b57-462d-868c-c075ffb040a4
# ╟─830aba1b-c6d1-4bfc-9c04-0a58f6966fd9
# ╟─0ec3bd71-1497-43be-9d96-7d445378b66d
# ╟─2e02a0fe-192c-42c9-b20e-672ad83041bd
# ╟─e39915c4-afc7-4f9b-81d1-ea4b87f67010
# ╟─7ffed666-976e-4b09-afb1-62e57f506ec9
# ╟─a549cda6-ffe9-4d53-8901-72a772ac4030
# ╠═ebc7edcb-b59c-4c9c-88dc-b7d7b63df26e
# ╟─de93410d-ea4a-4c96-bf1b-3e44c54f1b0d
# ╟─a414d369-d2b3-4134-84b9-2e6ac26f9e9a
# ╟─3775de97-2b1e-48b6-bec5-c5c572d15812
# ╟─5c09ffd1-be5f-4fa4-b4b0-fd6b44604bd1
# ╟─f0f6988f-b590-4ab4-b088-7a67ad1af196
# ╟─ed296d0f-5395-48d7-946f-a7a400801a8c
# ╟─93440b5b-e3e9-4eee-b9e8-ea6d0b7a9287
# ╟─9f0a60ef-5f58-4990-a7b9-43b62f4eaca2
# ╟─f0ba7797-0129-4e6e-9875-088d5e276fad
# ╟─8d96d7a0-f07e-498d-aac7-81e91cc237fd
# ╟─cac8d227-1c29-463e-a06f-ee34a446346d
# ╟─b9acc04f-83e7-4847-a042-c0906275c333
# ╟─355de7c5-d5c4-43ae-88eb-d3fb38a63e3e
# ╟─bc72113c-3b60-4271-afe4-f763c45b80a9
# ╟─ea62e80d-1110-4a3e-8d3d-ff5c202fe795
# ╟─828c3ac9-565c-4aa4-a2ab-92a13f930c7d
# ╟─e511500d-1830-4ef0-8824-fe08b2308dc3
# ╟─a0aeeb0f-8566-4285-9e52-babf94caad78
# ╟─a59abfd2-c6fd-40b3-9887-b59f198f9f7a
# ╟─2143b654-b15a-4b84-8997-eb8734cc4ca2
# ╟─247238b8-aef9-4a96-8892-590b32f822d5
# ╟─2436361d-d227-40ec-bd5f-887e22c46cc0
# ╟─f067f58d-74e7-4b58-a9aa-69df7503f559
# ╟─30248794-18ab-4779-8f4f-bce3c2c4a0a2
# ╟─f441278d-8b44-4fb2-a061-ee6360088177
# ╟─2361966e-972f-4521-8134-c49be48ae92f
# ╟─697fece3-4f08-4041-9d48-159d06c342ab
# ╠═db3b2a15-9c32-4361-b3cc-15e9ab0b165d
# ╟─f56ba891-4e6d-4af7-91c3-b8bc615b2a90
# ╟─ab7f1c7c-c3a2-4f20-957a-44a3c1bf0f6f
# ╟─9398b1bd-9513-4969-9f0c-c94867e14250
# ╟─7bfdc001-59ac-496d-b98a-87b6792ad245
# ╟─108a0ddf-f0b1-4b8c-af17-11fea5f4da29
# ╟─9b7a97dd-0d7b-4414-b41c-530bd05ece12
# ╟─1a501673-45e9-4dc8-a516-72e235679b5b
# ╟─adbc4189-fde1-4089-a91e-738ed8713e3e
# ╠═b369730d-87cc-42f5-8c55-913bcf953e03
# ╠═bd71d4c9-6bde-4b39-ac85-450732654487
# ╟─e8eac1f1-cb50-4869-939b-f000667f054e
# ╟─bb0849ae-c1f1-4cbe-92aa-8291039cd088
# ╟─c41d57d6-acab-43d9-8202-a0130223d961
# ╟─2c4b1a34-9215-4108-b293-1df907be1c48
# ╟─25b1c192-1213-490e-8f7b-12ad12bc17f3
# ╟─66088733-aeda-4580-99e5-17cf027c9efb
# ╟─6a992b69-8359-4898-baee-beb17a7ad3e2
# ╟─9c47ee9b-5990-47f8-83c0-8cb85f51be87
# ╟─5f84e4b7-2e65-4402-b1a8-bd2b43a56aa7
# ╟─27009076-3654-4513-ae66-375c3c03296d
# ╟─44a6ab14-24cf-4bef-8542-f211c6bb29ff
# ╟─fb4c3ba2-06aa-4dcf-b34e-21b340d8f69a
# ╟─cea2f32d-f419-49c2-8daa-45c3a62c0aab
# ╟─1f50d22d-db78-4382-8708-61614f576f27
# ╟─5bcb419b-db52-4a3b-8fb8-96cc1aafe6b6
# ╟─70237c4a-08b8-45a3-9f0d-897771ae4658
# ╟─0097eaef-53a7-4aab-b20d-4357f12eaf9b
# ╟─47283948-ecbd-4bf9-9695-a59dd21fafa8
# ╟─a91fa2b0-070d-44fc-9830-e6f6c236d62c
# ╟─d0050dd5-1398-460d-a28d-dc8a1e846b11
# ╟─365d69fc-5d2b-4b57-a426-601809e2ca42
# ╟─98ef493e-8e7b-4edc-9470-06d6d8f9c6a4
# ╟─b5f8267d-31ea-4e02-881e-26a1249221da
# ╟─626fb86c-1b4d-43a1-bf47-26a95402654c
# ╟─87cac9dc-3c77-4aca-bb20-6ad9b6e201b8
# ╟─ddaec933-a0f1-45b2-91cd-40c9d1308818
# ╟─b9236494-eb3a-4ba8-9196-92188e72fbdb
# ╟─d8e9d8d5-d32c-41a5-a634-ed79d1a780d9
# ╟─719d57fe-8e5e-472a-9a07-d40c34fcf10c
# ╟─3f83b209-e81c-4e7e-86c3-3076219212cb
# ╟─27398a1c-6c62-4f70-bad1-8d95f4fa27f3
# ╟─e53494ef-a6cd-4278-bac9-dfda713453f9
# ╟─b4b0d6f5-2135-4ba2-a234-14e5c9b37f8b
# ╟─4688f4e1-de7b-44d0-94ed-26e864ba2f34
# ╟─9f88959d-7765-4e32-b4b1-fc1ee4a57672
# ╟─c1ba126a-95b8-4998-b1eb-66b61197fc8f
# ╟─ff2c5b60-5f83-412f-9fd7-0bd2a2d405de
# ╟─6a8e0a9d-d727-4daf-a19c-b2fc44ff80c4
# ╟─1576ebf2-0cf9-4870-b12f-b484e081dd67
# ╟─b608842e-a6e5-4a96-baa2-3778e0c53349
# ╠═611932e2-de7a-4480-83cf-79ca5665edf5
# ╟─ab06f2b6-207b-47b8-a4bd-0831380b7abc
# ╟─fe7e0122-38ee-4490-b893-54e8a7d8ab07
# ╟─1728b392-427a-4f83-aa7e-c5c576d2f362
# ╟─4fa02903-e7f3-4e85-b42d-9e97edd42493
# ╟─00000000-0000-0000-0000-000000000001
# ╟─00000000-0000-0000-0000-000000000002
